@@ -232,8 +232,7 @@ private_type_record() {
 # has been appended since the last time we read it.
 #
 # Calling some of these functions causes temporary *.prev files to be
-# created that need to be cleaned up manually (usually by a given system
-# test's clean.sh script).
+# created.
 #
 # Note that unlike other nextpart*() functions, nextpartread() is not
 # meant to be directly used in system tests; its sole purpose is to
@@ -448,7 +447,7 @@ rndc_dumpdb() {
   __ret=0
   __dump_complete=0
   __server="${1}"
-  __ip="10.53.0.$(echo "${__server}" | tr -c -d "0-9")"
+  __ip="10.53.0.$(echo "${__server}" | tr -c -d '[:digit:]')"
 
   shift
   ${RNDC} -c ../_common/rndc.conf -p "${CONTROLPORT}" -s "${__ip}" dumpdb "$@" >"rndc.out.test${n}" 2>&1 || __ret=1
