@@ -284,6 +284,27 @@ if [ -x "$DIG" ]; then
   if [ $ret -ne 0 ]; then echo_i "failed"; fi
   status=$((status + ret))
 
+  n=$((n + 1))
+  echo_i "checking dig +coflag works ($n)"
+  ret=0
+  dig_with_opts +tcp @10.53.0.3 +coflag +qr example >dig.out.test$n || ret=1
+  grep "^; EDNS: version: 0, flags: co;" <dig.out.test$n >/dev/null || ret=1
+  check_ttl_range dig.out.test$n "SOA" 300 || ret=1
+  if [ $ret -ne 0 ]; then echo_i "failed"; fi
+  status=$((status + ret))
+
+  if [ $HAS_PYYAML -ne 0 ]; then
+    n=$((n + 1))
+    echo_i "checking dig +coflag +yaml works ($n)"
+    ret=0
+    dig_with_opts +yaml +tcp @10.53.0.3 +coflag +qr example >dig.out.test$n || ret=1
+    $PYTHON yamlget.py dig.out.test$n 0 message query_message_data OPT_PSEUDOSECTION EDNS flags >yamlget.out.test$n 2>&1 || ret=1
+    read -r value <yamlget.out.test$n
+    [ "$value" = "co" ] || ret=1
+    if [ $ret -ne 0 ]; then echo_i "failed"; fi
+    status=$((status + ret))
+  fi
+
   n=$((n + 1))
   echo_i "checking dig +raflag works ($n)"
   ret=0
@@ -1697,7 +1718,8 @@ if [ -x "$DELV" ]; then
 
   n=$((n + 1))
   echo_i "check NS output from delv +ns ($n)"
-  delv_with_opts -i +ns +nortrace +nostrace +nomtrace +novtrace +hint=../_common/root.hint ns example >delv.out.test$n || ret=1
+  ret=0
+  delv_with_opts -i +ns +nortrace +nostrace +nomtrace +novtrace +hint=root.hint ns example >delv.out.test$n || ret=1
   lines=$(awk '$1 == "example." && $4 == "NS" {print}' delv.out.test$n | wc -l)
   [ $lines -eq 2 ] || ret=1
   status=$((status + ret))
@@ -1705,7 +1727,7 @@ if [ -x "$DELV" ]; then
   n=$((n + 1))
   echo_i "checking delv +ns (no validation) ($n)"
   ret=0
-  delv_with_opts -i +ns +hint=../_common/root.hint a a.example >delv.out.test$n || ret=1
+  delv_with_opts -i +ns +hint=root.hint a a.example >delv.out.test$n || ret=1
   grep -q '; authoritative' delv.out.test$n || ret=1
   grep -q '_.example' delv.out.test$n && ret=1
   if [ $ret -ne 0 ]; then echo_i "failed"; fi
@@ -1714,7 +1736,7 @@ if [ -x "$DELV" ]; then
   n=$((n + 1))
   echo_i "checking delv +ns +qmin (no validation) ($n)"
   ret=0
-  delv_with_opts -i +ns +qmin +hint=../_common/root.hint a a.example >delv.out.test$n || ret=1
+  delv_with_opts -i +ns +qmin +hint=root.hint a a.example >delv.out.test$n || ret=1
   grep -q '; authoritative' delv.out.test$n || ret=1
   if [ $ret -ne 0 ]; then echo_i "failed"; fi
   status=$((status + ret))
@@ -1722,7 +1744,7 @@ if [ -x "$DELV" ]; then
   n=$((n + 1))
   echo_i "checking delv +ns (with validation) ($n)"
   ret=0
-  delv_with_opts -a ns1/anchor.dnskey +root +ns +hint=../_common/root.hint a a.example >delv.out.test$n || ret=1
+  delv_with_opts -a ns1/anchor.dnskey +root +ns +hint=root.hint a a.example >delv.out.test$n || ret=1
   grep -q '; fully validated' delv.out.test$n || ret=1
   grep -q '_.example' delv.out.test$n && ret=1
   if [ $ret -ne 0 ]; then echo_i "failed"; fi
@@ -1731,11 +1753,31 @@ if [ -x "$DELV" ]; then
   n=$((n + 1))
   echo_i "checking delv +ns +qmin (with validation) ($n)"
   ret=0
-  delv_with_opts -a ns1/anchor.dnskey +root +ns +qmin +hint=../_common/root.hint a a.example >delv.out.test$n || ret=1
+  delv_with_opts -a ns1/anchor.dnskey +root +ns +qmin +hint=root.hint a a.example >delv.out.test$n || ret=1
   grep -q '; fully validated' delv.out.test$n || ret=1
   if [ $ret -ne 0 ]; then echo_i "failed"; fi
   status=$((status + ret))
 
+  if testsock6 fd92:7065:b8e:ffff::2 2>/dev/null; then
+    n=$((n + 1))
+    echo_i "checking delv -4 +ns uses only IPv4 ($n)"
+    ret=0
+    delv_with_opts -a ns1/anchor.dnskey +root -4 +ns +hint=root.hint a a.example >delv.out.test$n || ret=1
+    grep -qF 'sending packet to 10.53' delv.out.test$n >/dev/null || ret=1
+    grep -qF 'sending packet to fd92:7065' delv.out.test$n >/dev/null && ret=1
+    if [ $ret -ne 0 ]; then echo_i "failed"; fi
+    status=$((status + ret))
+
+    n=$((n + 1))
+    echo_i "checking delv -6 +ns uses only IPv6 ($n)"
+    ret=0
+    delv_with_opts -a ns1/anchor.dnskey +root -6 +ns +hint=root.hint a a.example >delv.out.test$n || ret=1
+    grep -qF 'sending packet to 10.53' delv.out.test$n >/dev/null && ret=1
+    grep -qF 'sending packet to fd92:7065' delv.out.test$n >/dev/null || ret=1
+    if [ $ret -ne 0 ]; then echo_i "failed"; fi
+    status=$((status + ret))
+  fi
+
 else
   echo_i "$DELV is needed, so skipping these delv tests"
 fi
