@@ -9,12 +9,12 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+import dns
 from dns import rdataclass, rdatatype
 
-import dns.name
-
 import isctest
 
+
 ARTIFACTS = [
     "conf/*.conf",
     "ns*/trusted.conf",
@@ -25,6 +25,14 @@ ARTIFACTS = [
 ]
 
 
+def reconfigure_servers(ftype, family, servers, templates):
+    for server_id in ["ns1", "ns2", "ns3", "ns4"]:
+        templates.render(
+            f"{server_id}/named.conf", {"family": family, "filtertype": ftype}
+        )
+        servers[server_id].reconfigure(log=False)
+
+
 def check_filtertype_only(dest, source, qname, ftype, expected, adflag):
     qname = dns.name.from_text(qname)
 
