@@ -11,14 +11,20 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-from typing import NamedTuple, Optional
+from typing import List, NamedTuple, Optional
 
 import logging
 import os
+from pathlib import Path
 import re
 
+import dns.message
+import dns.rcode
+
+from .log import debug, info, LogFile, WatchLogFromStart, WatchLogFromHere
 from .rndc import RNDCBinaryExecutor, RNDCException, RNDCExecutor
-from .log import info, LogFile, WatchLogFromStart, WatchLogFromHere
+from .run import perl
+from .query import udp
 
 
 class NamedPorts(NamedTuple):
@@ -45,17 +51,20 @@ class NamedInstance:
     ```
     """
 
-    # pylint: disable=too-many-arguments
     def __init__(
         self,
         identifier: str,
+        num: Optional[int] = None,
         ports: Optional[NamedPorts] = None,
         rndc_logger: Optional[logging.Logger] = None,
         rndc_executor: Optional[RNDCExecutor] = None,
     ) -> None:
         """
-        `identifier` must be an `ns<X>` string, where `<X>` is an integer
-        identifier of the `named` instance this object should represent.
+        `identifier` is the name of the instance's directory
+
+        `num` is optional if the identifier is in a form of `ns<X>`, in which
+        case `<X>` is assumed to be numeric identifier; otherwise it must be
+        provided to assign a numeric identification to the server
 
         `ports` is the `NamedPorts` instance listing the UDP/TCP ports on which
         this `named` instance is listening for various types of traffic (both
@@ -68,7 +77,13 @@ class NamedInstance:
         `rndc_executor` is an object implementing the `RNDCExecutor` interface
         that is used for executing RNDC commands on this `named` instance.
         """
-        self.ip = self._identifier_to_ip(identifier)
+        self.directory = Path(identifier).absolute()
+        if not self.directory.is_dir():
+            raise ValueError(f"{self.directory} isn't a directory")
+        self.system_test_name = self.directory.parent.name
+
+        self.identifier = identifier
+        self.num = self._identifier_to_num(identifier, num)
         if ports is None:
             ports = NamedPorts.from_env()
         self.ports = ports
@@ -76,12 +91,21 @@ class NamedInstance:
         self._rndc_executor = rndc_executor or RNDCBinaryExecutor()
         self._rndc_logger = rndc_logger
 
+    @property
+    def ip(self) -> str:
+        """IPv4 address of the instance."""
+        return f"10.53.0.{self.num}"
+
     @staticmethod
-    def _identifier_to_ip(identifier: str) -> str:
+    def _identifier_to_num(identifier: str, num: Optional[int] = None) -> int:
         regex_match = re.match(r"^ns(?P<index>[0-9]{1,2})$", identifier)
         if not regex_match:
-            raise ValueError("Invalid named instance identifier" + identifier)
-        return "10.53.0." + regex_match.group("index")
+            if num is None:
+                raise ValueError(f'Can\'t parse numeric identifier from "{identifier}"')
+            return num
+        parsed_num = int(regex_match.group("index"))
+        assert num is None or num == parsed_num, "mismatched num and identifier"
+        return parsed_num
 
     def rndc(self, command: str, ignore_errors: bool = False, log: bool = True) -> str:
         """
@@ -94,35 +118,28 @@ class NamedInstance:
         The RNDC command will be logged to `rndc.log` (along with the server's
         response) unless `log` is set to `False`.
 
-        >>> # Instances of the `NamedInstance` class are expected to be passed
-        >>> # to pytest tests as fixtures; here, some instances are created
-        >>> # directly (with a fake RNDC executor) so that doctest can work.
-        >>> import unittest.mock
-        >>> mock_rndc_executor = unittest.mock.Mock()
-        >>> ns1 = NamedInstance("ns1", rndc_executor=mock_rndc_executor)
-        >>> ns2 = NamedInstance("ns2", rndc_executor=mock_rndc_executor)
-        >>> ns3 = NamedInstance("ns3", rndc_executor=mock_rndc_executor)
-        >>> ns4 = NamedInstance("ns4", rndc_executor=mock_rndc_executor)
+        ```python
+        def test_foo(servers):
+            # Send the "status" command to ns1.  An `RNDCException` will be
+            # raised if the RNDC command fails.  This command will be logged.
+            response = servers["ns1"].rndc("status")
 
-        >>> # Send the "status" command to ns1.  An `RNDCException` will be
-        >>> # raised if the RNDC command fails.  This command will be logged.
-        >>> response = ns1.rndc("status")
+            # Send the "thaw foo" command to ns2.  No exception will be raised
+            # in case the RNDC command fails.  This command will be logged
+            # (even if it fails).
+            response = servers["ns2"].rndc("thaw foo", ignore_errors=True)
 
-        >>> # Send the "thaw foo" command to ns2.  No exception will be raised
-        >>> # in case the RNDC command fails.  This command will be logged
-        >>> # (even if it fails).
-        >>> response = ns2.rndc("thaw foo", ignore_errors=True)
+            # Send the "stop" command to ns3.  An `RNDCException` will be
+            # raised if the RNDC command fails, but this command will not be
+            # logged (the server's response will still be returned to the
+            # caller, though).
+            response = servers["ns3"].rndc("stop", log=False)
 
-        >>> # Send the "stop" command to ns3.  An `RNDCException` will be
-        >>> # raised if the RNDC command fails, but this command will not be
-        >>> # logged (the server's response will still be returned to the
-        >>> # caller, though).
-        >>> response = ns3.rndc("stop", log=False)
-
-        >>> # Send the "halt" command to ns4 in "fire & forget mode": no
-        >>> # exceptions will be raised and no logging will take place (the
-        >>> # server's response will still be returned to the caller, though).
-        >>> response = ns4.rndc("stop", ignore_errors=True, log=False)
+            # Send the "halt" command to ns4 in "fire & forget mode": no
+            # exceptions will be raised and no logging will take place (the
+            # server's response will still be returned to the caller, though).
+            response = servers["ns4"].rndc("stop", ignore_errors=True, log=False)
+        ```
         """
         try:
             response = self._rndc_executor.call(self.ip, self.ports.rndc, command)
@@ -137,27 +154,53 @@ class NamedInstance:
 
         return response
 
-    def watch_log_from_start(self) -> WatchLogFromStart:
+    def nsupdate(self, update_msg: dns.message.Message):
+        """
+        Issue a dynamic update to a server's zone.
+        """
+        # FUTURE update_msg is actually dns.update.UpdateMessage, but it not
+        # typed properly here in order to support use of this module with
+        # dnspython<2.0.0
+        zone = str(update_msg.zone[0].name)  # type: ignore[attr-defined]
+        try:
+            response = udp(
+                update_msg,
+                self.ip,
+                self.ports.dns,
+                timeout=3,
+                expected_rcode=dns.rcode.NOERROR,
+            )
+        except dns.exception.Timeout as exc:
+            msg = f"update timeout for {zone}"
+            raise dns.exception.Timeout(msg) from exc
+        debug(f"update of zone {zone} to server {self.ip} successful")
+        return response
+
+    def watch_log_from_start(
+        self, timeout: float = WatchLogFromStart.DEFAULT_TIMEOUT
+    ) -> WatchLogFromStart:
         """
         Return an instance of the `WatchLogFromStart` context manager for this
         `named` instance's log file.
         """
-        return WatchLogFromStart(self.log.path)
+        return WatchLogFromStart(self.log.path, timeout)
 
-    def watch_log_from_here(self) -> WatchLogFromHere:
+    def watch_log_from_here(
+        self, timeout: float = WatchLogFromHere.DEFAULT_TIMEOUT
+    ) -> WatchLogFromHere:
         """
         Return an instance of the `WatchLogFromHere` context manager for this
         `named` instance's log file.
         """
-        return WatchLogFromHere(self.log.path)
+        return WatchLogFromHere(self.log.path, timeout)
 
-    def reconfigure(self) -> None:
+    def reconfigure(self, **kwargs) -> None:
         """
         Reconfigure this named `instance` and wait until reconfiguration is
         finished.  Raise an `RNDCException` if reconfiguration fails.
         """
         with self.watch_log_from_here() as watcher:
-            self.rndc("reconfig")
+            self.rndc("reconfig", **kwargs)
             watcher.wait_for_line("any newly configured zones are now loaded")
 
     def _rndc_log(self, command: str, response: str) -> None:
@@ -176,3 +219,19 @@ class NamedInstance:
             info(fmt, args)
         else:
             self._rndc_logger.info(fmt, args)
+
+    def stop(self, args: Optional[List[str]] = None) -> None:
+        """Stop the instance."""
+        args = args or []
+        perl(
+            f"{os.environ['srcdir']}/stop.pl",
+            [self.system_test_name, self.identifier] + args,
+        )
+
+    def start(self, args: Optional[List[str]] = None) -> None:
+        """Start the instance."""
+        args = args or []
+        perl(
+            f"{os.environ['srcdir']}/start.pl",
+            [self.system_test_name, self.identifier] + args,
+        )
