@@ -118,6 +118,7 @@ lifetime = {
     "P1Y": int(timedelta(days=365).total_seconds()),
     "P30D": int(timedelta(days=30).total_seconds()),
     "P6M": int(timedelta(days=31 * 6).total_seconds()),
+    "P2M": int(timedelta(days=31 * 2).total_seconds()),
 }
 
 KASP_INHERIT_TSIG_SECRET = {
@@ -157,10 +158,18 @@ def fips_properties(alg, bits=None):
     ]
 
 
-def check_all(server, zone, policy, ksks, zsks, zsk_missing=False, tsig=None):
+def check_all(
+    server, zone, policy, ksks, zsks, manual_mode=False, zsk_missing=False, tsig=None
+):
     isctest.kasp.check_dnssecstatus(server, zone, ksks + zsks, policy=policy)
     isctest.kasp.check_apex(
-        server, zone, ksks, zsks, zsk_missing=zsk_missing, tsig=tsig
+        server,
+        zone,
+        ksks,
+        zsks,
+        manual_mode=manual_mode,
+        zsk_missing=zsk_missing,
+        tsig=tsig,
     )
     isctest.kasp.check_subdomain(server, zone, ksks, zsks, tsig=tsig)
 
@@ -203,7 +212,7 @@ def cb_ixfr_is_signed(expected_updates, params, ksks=None, zsks=None):
         )
 
     for update in expected_updates:
-        isctest.run.retry_with_timeout(update_is_signed, timeout=5)
+        isctest.run.retry_with_timeout(update_is_signed, timeout=10)
 
 
 def cb_rrsig_refresh(params, ksks=None, zsks=None):
@@ -586,6 +595,9 @@ def cb_remove_keyfiles(params, ksks=None, zsks=None):
                 ],
             },
             id="secondary.kasp",
+            marks=pytest.mark.flaky(
+                max_runs=2, rerun_filter=isctest.mark.is_host_freebsd_13
+            ),
         ),
         pytest.param(
             {
@@ -630,16 +642,17 @@ def cb_remove_keyfiles(params, ksks=None, zsks=None):
         ),
     ],
 )
-def test_kasp_case(servers, params):
+def test_kasp_case(servers, ns3, params):
     # Test many different configurations and expected keys and states after
     # initial startup.
-    server = servers["ns3"]
-    keydir = server.identifier
+    keydir = ns3.identifier
 
     # Get test parameters.
     zone = params["zone"]
     policy = params["policy"]
 
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     params["config"]["key-directory"] = params["config"]["key-directory"].replace(
         "{keydir}", keydir
     )
@@ -657,7 +670,7 @@ def test_kasp_case(servers, params):
     isctest.log.info(f"check test case zone {zone} policy {policy}")
 
     # First make sure the zone is signed.
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
 
     # Key properties.
     expected = isctest.kasp.policy_to_properties(ttl=ttl, keys=params["key-properties"])
@@ -675,7 +688,7 @@ def test_kasp_case(servers, params):
         ksks = [k for k in keys if k.is_ksk()]
         zsks = [k for k in keys if not k.is_ksk()]
 
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
 
     offset = params["offset"] if "offset" in params else None
@@ -688,7 +701,7 @@ def test_kasp_case(servers, params):
     if "rumoured" not in params:
         isctest.kasp.check_keytimes(keys, expected)
 
-    check_all(server, zone, policy, ksks, zsks, zsk_missing=zsk_missing)
+    check_all(ns3, zone, policy, ksks, zsks, zsk_missing=zsk_missing)
 
     if "additional-tests" in params:
         params["servers"] = servers
@@ -751,6 +764,8 @@ def test_kasp_inherit_signed(zone, policy, server_id, alg, tsig_kind, servers):
         else None
     )
 
+    isctest.kasp.wait_keymgr_done(server, zone)
+
     key1 = KeyProperties.default()
     key1.metadata["Algorithm"] = alg.number
     key1.metadata["Length"] = alg.bits
@@ -771,26 +786,27 @@ def test_kasp_inherit_signed(zone, policy, server_id, alg, tsig_kind, servers):
         param("3", "no", "yes", "view2"),
     ],
 )
-def test_kasp_inherit_view(number, dynamic, inline_signing, txt_rdata, servers):
+def test_kasp_inherit_view(number, dynamic, inline_signing, txt_rdata, ns4):
     zone = "example.net"
     policy = "test"
-    server = servers["ns4"]
     view = f"example{number}"
     tsig = f"{os.environ['DEFAULT_HMAC']}:keyforview{number}:{KASP_INHERIT_TSIG_SECRET[f'view{number}']}"
 
+    isctest.kasp.wait_keymgr_done(ns4, zone)
+
     key1 = KeyProperties.default()
     key1.metadata["Algorithm"] = ECDSAP384SHA384.number
     key1.metadata["Length"] = ECDSAP384SHA384.bits
-    keys = isctest.kasp.keydir_to_keylist(zone, server.identifier)
+    keys = isctest.kasp.keydir_to_keylist(zone, ns4.identifier)
 
-    isctest.kasp.check_dnssec_verify(server, zone, tsig=tsig)
+    isctest.kasp.check_dnssec_verify(ns4, zone, tsig=tsig)
     isctest.kasp.check_keys(zone, keys, [key1])
     set_keytimes_default_policy(key1)
     isctest.kasp.check_keytimes(keys, [key1])
-    isctest.kasp.check_dnssecstatus(server, zone, keys, policy=policy, view=view)
-    isctest.kasp.check_apex(server, zone, keys, [], tsig=tsig)
+    isctest.kasp.check_dnssecstatus(ns4, zone, keys, policy=policy, view=view)
+    isctest.kasp.check_apex(ns4, zone, keys, [], tsig=tsig)
     # check zonestatus
-    response = server.rndc(f"zonestatus {zone} in {view}", log=False)
+    response = ns4.rndc(f"zonestatus {zone} in {view}", log=False)
     assert f"dynamic: {dynamic}" in response
     assert f"inline signing: {inline_signing}" in response
     # check subdomain
@@ -798,14 +814,14 @@ def test_kasp_inherit_view(number, dynamic, inline_signing, txt_rdata, servers):
     qname = f"view.{zone}."
     qtype = dns.rdatatype.TXT
     rdata = txt_rdata
-    query = dns.message.make_query(qname, qtype, use_edns=True, want_dnssec=True)
+    query = isctest.query.create(qname, qtype)
     tsigkey = tsig.split(":")
     keyring = dns.tsig.Key(tsigkey[1], tsigkey[2], tsigkey[0])
     query.use_tsig(keyring)
     try:
-        response = isctest.query.tcp(query, server.ip, server.ports.dns, timeout=3)
+        response = isctest.query.tcp(query, ns4.ip, ns4.ports.dns, timeout=3)
     except dns.exception.Timeout:
-        isctest.log.debug(f"query timeout for query {qname} {qtype} to {server.ip}")
+        isctest.log.debug(f"query timeout for query {qname} {qtype} to {ns4.ip}")
         response = None
     assert response.rcode() == dns.rcode.NOERROR
     match = f'{qname} 300 IN TXT "{rdata}"'
@@ -821,14 +837,14 @@ def test_kasp_inherit_view(number, dynamic, inline_signing, txt_rdata, servers):
     isctest.kasp.check_signatures(rrsigs, qtype, fqdn, keys, [])
 
 
-def test_kasp_default(servers):
-    server = servers["ns3"]
-
+def test_kasp_default(ns3):
     # check the zone with default kasp policy has loaded and is signed.
     isctest.log.info("check a zone with the default policy is signed")
     zone = "default.kasp"
     policy = "default"
 
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # Key properties.
     # DNSKEY, RRSIG (ksk), RRSIG (zsk) are published. DS needs to wait.
     keyprops = [
@@ -836,11 +852,11 @@ def test_kasp_default(servers):
     ]
     expected = isctest.kasp.policy_to_properties(ttl=3600, keys=keyprops)
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
     set_keytimes_default_policy(expected[0])
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
     # Trigger a keymgr run. Make sure the key files are not touched if there
     # are no modifications to the key metadata.
@@ -852,8 +868,8 @@ def test_kasp_default(servers):
     pubkey_stat = os.stat(key.keyfile)
     state_stat = os.stat(key.statefile)
 
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"loadkeys {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"loadkeys {zone}", log=False)
         watcher.wait_for_line(f"keymgr: {zone} done")
 
     assert privkey_stat.st_mtime == os.stat(key.privatefile).st_mtime
@@ -861,8 +877,8 @@ def test_kasp_default(servers):
     assert state_stat.st_mtime == os.stat(key.statefile).st_mtime
 
     # again
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"loadkeys {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"loadkeys {zone}", log=False)
         watcher.wait_for_line(f"keymgr: {zone} done")
 
     assert privkey_stat.st_mtime == os.stat(key.privatefile).st_mtime
@@ -872,7 +888,7 @@ def test_kasp_default(servers):
     # modify unsigned zone file and check that new record is signed.
     isctest.log.info("check that an updated zone signs the new record")
     shutil.copyfile("ns3/template2.db.in", f"ns3/{zone}.db")
-    server.rndc(f"reload {zone}", log=False)
+    ns3.rndc(f"reload {zone}", log=False)
 
     def update_is_signed():
         parts = update.split()
@@ -880,7 +896,7 @@ def test_kasp_default(servers):
         qtype = dns.rdatatype.from_text(parts[1])
         rdata = parts[2]
         return isctest.kasp.verify_update_is_signed(
-            server, zone, qname, qtype, rdata, keys, []
+            ns3, zone, qname, qtype, rdata, keys, []
         )
 
     expected_updates = [f"a.{zone}. A 10.0.0.11", f"d.{zone}. A 10.0.0.44"]
@@ -892,48 +908,51 @@ def test_kasp_default(servers):
     isctest.log.info("check that missing private key doesn't trigger rollover")
     shutil.move(f"{key.privatefile}", f"{key.path}.offline")
     expectmsg = "zone_rekey:zone_verifykeys failed: some key files are missing"
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"loadkeys {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"loadkeys {zone}", log=False)
         watcher.wait_for_line(f"zone {zone}/IN (signed): {expectmsg}")
     # Nothing has changed.
     expected[0].properties["private"] = False
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
     # A zone that uses inline-signing.
     isctest.log.info("check an inline-signed zone with the default policy is signed")
     zone = "inline-signing.kasp"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # Key properties.
     key1 = KeyProperties.default()
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     expected = [key1]
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
     set_keytimes_default_policy(key1)
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
 
-def test_kasp_dynamic(servers):
-    # Dynamic update test cases.
-    server = servers["ns3"]
-
+def test_kasp_dynamic(ns3):
     # Standard dynamic zone.
     isctest.log.info("check dynamic zone is updated and signed after update")
     zone = "dynamic.kasp"
     policy = "default"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # Key properties.
     key1 = KeyProperties.default()
     expected = [key1]
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
     set_keytimes_default_policy(key1)
     expected = [key1]
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
     def update_is_signed():
         parts = update.split()
@@ -941,14 +960,14 @@ def test_kasp_dynamic(servers):
         qtype = dns.rdatatype.from_text(parts[1])
         rdata = parts[2]
         return isctest.kasp.verify_update_is_signed(
-            server, zone, qname, qtype, rdata, keys, []
+            ns3, zone, qname, qtype, rdata, keys, []
         )
 
     update_msg = dns.update.UpdateMessage(zone)
     update_msg.delete(f"a.{zone}.", "A", "10.0.0.1")
     update_msg.add(f"a.{zone}.", 300, "A", "10.0.0.101")
     update_msg.add(f"d.{zone}.", 300, "A", "10.0.0.4")
-    server.nsupdate(update_msg)
+    ns3.nsupdate(update_msg)
 
     expected_updates = [f"a.{zone}. A 10.0.0.101", f"d.{zone}. A 10.0.0.4"]
     for update in expected_updates:
@@ -959,15 +978,15 @@ def test_kasp_dynamic(servers):
     update_msg.add(f"a.{zone}.", 300, "A", "10.0.0.1")
     update_msg.delete(f"a.{zone}.", "A", "10.0.0.101")
     update_msg.delete(f"d.{zone}.", "A", "10.0.0.4")
-    server.nsupdate(update_msg)
+    ns3.nsupdate(update_msg)
 
     update = f"a.{zone}. A 10.0.0.1"
     isctest.run.retry_with_timeout(update_is_signed, timeout=5)
 
     # Update zone with freeze/thaw.
     isctest.log.info("check dynamic zone is updated and signed after freeze and thaw")
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"freeze {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"freeze {zone}", log=False)
         watcher.wait_for_line(f"freezing zone '{zone}/IN': success")
 
     time.sleep(1)
@@ -975,8 +994,8 @@ def test_kasp_dynamic(servers):
         zonefile.write(f"d.{zone}. 300 A 10.0.0.44\n")
     time.sleep(1)
 
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"thaw {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"thaw {zone}", log=False)
         watcher.wait_for_line(f"thawing zone '{zone}/IN': success")
 
     expected_updates = [f"a.{zone}. A 10.0.0.1", f"d.{zone}. A 10.0.0.44"]
@@ -986,31 +1005,34 @@ def test_kasp_dynamic(servers):
 
     # Dynamic, and inline-signing.
     zone = "dynamic-inline-signing.kasp"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # Key properties.
     key1 = KeyProperties.default()
     expected = [key1]
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
     set_keytimes_default_policy(key1)
     expected = [key1]
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
     # Update zone with freeze/thaw.
     isctest.log.info(
         "check dynamic inline-signed zone is updated and signed after freeze and thaw"
     )
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"freeze {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"freeze {zone}", log=False)
         watcher.wait_for_line(f"freezing zone '{zone}/IN': success")
 
     time.sleep(1)
     shutil.copyfile("ns3/template2.db.in", f"ns3/{zone}.db")
     time.sleep(1)
 
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"thaw {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"thaw {zone}", log=False)
         watcher.wait_for_line(f"thawing zone '{zone}/IN': success")
 
     expected_updates = [f"a.{zone}. A 10.0.0.11", f"d.{zone}. A 10.0.0.44"]
@@ -1020,6 +1042,9 @@ def test_kasp_dynamic(servers):
     # Dynamic, signed, and inline-signing.
     isctest.log.info("check dynamic signed, and inline-signed zone")
     zone = "dynamic-signed-inline-signing.kasp"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # Key properties.
     key1 = KeyProperties.default()
     # The ns3/setup.sh script sets all states to omnipresent.
@@ -1029,16 +1054,14 @@ def test_kasp_dynamic(servers):
     key1.metadata["DSState"] = "omnipresent"
     expected = [key1]
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3/keys")
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
     # Ensure no zone_resigninc for the unsigned version of the zone is triggered.
     assert f"zone_resigninc: zone {zone}/IN (unsigned): enter" not in "ns3/named.run"
 
 
-def test_kasp_checkds(servers):
-    server = servers["ns3"]
-
+def test_kasp_checkds(ns3):
     def wait_for_metadata():
         return isctest.util.file_contents_contain(ksk.statefile, metadata)
 
@@ -1051,19 +1074,22 @@ def test_kasp_checkds(servers):
         f"ksk unlimited {alg} {size} goal:omnipresent dnskey:rumoured krrsig:rumoured ds:hidden",
         f"zsk unlimited {alg} {size} goal:omnipresent dnskey:rumoured zrrsig:rumoured",
     ]
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     expected = isctest.kasp.policy_to_properties(ttl=303, keys=policy_keys)
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     ksks = [k for k in keys if k.is_ksk()]
     zsks = [k for k in keys if k.is_zsk()]
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
-    check_all(server, zone, policy, ksks, zsks)
+    check_all(ns3, zone, policy, ksks, zsks)
 
     now = KeyTimingMetadata.now()
     ksk = ksks[0]
 
     isctest.log.info("check if checkds -publish correctly sets DSPublish")
-    server.rndc(f"dnssec -checkds -when {now} published {zone}", log=False)
+    ns3.rndc(f"dnssec -checkds -when {now} published {zone}", log=False)
     metadata = f"DSPublish: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[0].metadata["DSState"] = "rumoured"
@@ -1071,7 +1097,7 @@ def test_kasp_checkds(servers):
     isctest.kasp.check_keys(zone, keys, expected)
 
     isctest.log.info("check if checkds -withdrawn correctly sets DSRemoved")
-    server.rndc(f"dnssec -checkds -when {now} withdrawn {zone}", log=False)
+    ns3.rndc(f"dnssec -checkds -when {now} withdrawn {zone}", log=False)
     metadata = f"DSRemoved: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[0].metadata["DSState"] = "unretentive"
@@ -1079,9 +1105,7 @@ def test_kasp_checkds(servers):
     isctest.kasp.check_keys(zone, keys, expected)
 
 
-def test_kasp_checkds_doubleksk(servers):
-    server = servers["ns3"]
-
+def test_kasp_checkds_doubleksk(ns3):
     def wait_for_metadata():
         return isctest.util.file_contents_contain(ksk.statefile, metadata)
 
@@ -1095,13 +1119,16 @@ def test_kasp_checkds_doubleksk(servers):
         f"ksk unlimited {alg} {size} goal:omnipresent dnskey:rumoured krrsig:rumoured ds:hidden",
         f"zsk unlimited {alg} {size} goal:omnipresent dnskey:rumoured zrrsig:rumoured",
     ]
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     expected = isctest.kasp.policy_to_properties(ttl=303, keys=policy_keys)
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     ksks = [k for k in keys if k.is_ksk()]
     zsks = [k for k in keys if k.is_zsk()]
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
-    check_all(server, zone, policy, ksks, zsks)
+    check_all(ns3, zone, policy, ksks, zsks)
 
     now = KeyTimingMetadata.now()
     ksk = ksks[0]
@@ -1110,7 +1137,7 @@ def test_kasp_checkds_doubleksk(servers):
     isctest.log.info("check invalid checkds commands")
 
     def check_error():
-        response = server.rndc(test["command"], log=False)
+        response = ns3.rndc(test["command"], log=False)
         assert test["error"] in response
 
     test_cases = [
@@ -1135,9 +1162,7 @@ def test_kasp_checkds_doubleksk(servers):
         check_error()
 
     isctest.log.info("check if checkds -publish -key correctly sets DSPublish")
-    server.rndc(
-        f"dnssec -checkds -when {now} -key {ksk.tag} published {zone}", log=False
-    )
+    ns3.rndc(f"dnssec -checkds -when {now} -key {ksk.tag} published {zone}", log=False)
     metadata = f"DSPublish: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[0].metadata["DSState"] = "rumoured"
@@ -1146,9 +1171,7 @@ def test_kasp_checkds_doubleksk(servers):
 
     isctest.log.info("check if checkds -withdrawn -key correctly sets DSRemoved")
     ksk = ksks[1]
-    server.rndc(
-        f"dnssec -checkds -when {now} -key {ksk.tag} withdrawn {zone}", log=False
-    )
+    ns3.rndc(f"dnssec -checkds -when {now} -key {ksk.tag} withdrawn {zone}", log=False)
     metadata = f"DSRemoved: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[1].metadata["DSState"] = "unretentive"
@@ -1156,9 +1179,7 @@ def test_kasp_checkds_doubleksk(servers):
     isctest.kasp.check_keys(zone, keys, expected)
 
 
-def test_kasp_checkds_csk(servers):
-    server = servers["ns3"]
-
+def test_kasp_checkds_csk(ns3):
     def wait_for_metadata():
         return isctest.util.file_contents_contain(ksk.statefile, metadata)
 
@@ -1170,17 +1191,20 @@ def test_kasp_checkds_csk(servers):
     policy_keys = [
         f"csk unlimited {alg} {size} goal:omnipresent dnskey:rumoured krrsig:rumoured zrrsig:rumoured ds:hidden",
     ]
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     expected = isctest.kasp.policy_to_properties(ttl=303, keys=policy_keys)
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
-    check_all(server, zone, policy, keys, [])
+    check_all(ns3, zone, policy, keys, [])
 
     now = KeyTimingMetadata.now()
     ksk = keys[0]
 
     isctest.log.info("check if checkds -publish csk correctly sets DSPublish")
-    server.rndc(f"dnssec -checkds -when {now} published {zone}", log=False)
+    ns3.rndc(f"dnssec -checkds -when {now} published {zone}", log=False)
     metadata = f"DSPublish: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[0].metadata["DSState"] = "rumoured"
@@ -1188,7 +1212,7 @@ def test_kasp_checkds_csk(servers):
     isctest.kasp.check_keys(zone, keys, expected)
 
     isctest.log.info("check if checkds -withdrawn csk correctly sets DSRemoved")
-    server.rndc(f"dnssec -checkds -when {now} withdrawn {zone}", log=False)
+    ns3.rndc(f"dnssec -checkds -when {now} withdrawn {zone}", log=False)
     metadata = f"DSRemoved: {now}"
     isctest.run.retry_with_timeout(wait_for_metadata, timeout=3)
     expected[0].metadata["DSState"] = "unretentive"
@@ -1196,50 +1220,50 @@ def test_kasp_checkds_csk(servers):
     isctest.kasp.check_keys(zone, keys, expected)
 
 
-def test_kasp_special_characters(servers):
-    server = servers["ns3"]
-
+def test_kasp_special_characters(ns3):
     # A zone with special characters.
     isctest.log.info("check special characters")
 
-    zone = r'i-am.":\;?&[]\@!\$*+,|=\.\(\)special.kasp'
+    zone = r"i-am.\":\;?&[]\@!\$*+,|=\.\(\)special.kasp"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     # It is non-trivial to adapt the tests to deal with all possible different
     # escaping characters, so we will just try to verify the zone.
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
 
 
-def test_kasp_insecure(servers):
-    server = servers["ns3"]
-
+def test_kasp_insecure(ns3):
     # Insecure zones.
     isctest.log.info("check insecure zones")
 
     zone = "insecure.kasp"
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     expected = []
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     isctest.kasp.check_keys(zone, keys, expected)
-    isctest.kasp.check_dnssecstatus(server, zone, keys, policy="insecure")
-    isctest.kasp.check_apex(server, zone, keys, [])
-    isctest.kasp.check_subdomain(server, zone, keys, [])
+    isctest.kasp.check_dnssecstatus(ns3, zone, keys, policy="insecure")
+    isctest.kasp.check_apex(ns3, zone, keys, [])
+    isctest.kasp.check_subdomain(ns3, zone, keys, [])
 
     zone = "unsigned.kasp"
     expected = []
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     isctest.kasp.check_keys(zone, keys, expected)
-    isctest.kasp.check_dnssecstatus(server, zone, keys, policy=None)
-    isctest.kasp.check_apex(server, zone, keys, [])
-    isctest.kasp.check_subdomain(server, zone, keys, [])
+    isctest.kasp.check_dnssecstatus(ns3, zone, keys, policy=None)
+    isctest.kasp.check_apex(ns3, zone, keys, [])
+    isctest.kasp.check_subdomain(ns3, zone, keys, [])
     # Make sure the zone file is untouched.
     isctest.check.file_contents_equal(f"ns3/{zone}.db.infile", f"ns3/{zone}.db")
 
 
-def test_kasp_bad_maxzonettl(servers):
-    server = servers["ns3"]
-
+def test_kasp_bad_maxzonettl(ns3):
     # check that max-zone-ttl rejects zones with too high TTL.
     isctest.log.info("check max-zone-ttl rejects zones with too high TTL")
     zone = "max-zone-ttl.kasp"
-    assert f"loading from master file {zone}.db failed: out of range" in server.log
+    assert f"loading from master file {zone}.db failed: out of range" in ns3.log
 
 
 def test_kasp_dnssec_keygen():
@@ -1428,9 +1452,7 @@ def test_kasp_dnssec_keygen():
     isctest.kasp.check_keytimes(keys, expected)
 
 
-def test_kasp_zsk_retired(servers):
-    server = servers["ns3"]
-
+def test_kasp_zsk_retired(ns3):
     config = {
         "dnskey-ttl": timedelta(seconds=300),
         "ds-ttl": timedelta(days=1),
@@ -1454,11 +1476,14 @@ def test_kasp_zsk_retired(servers):
         # zsk successor
         f"zsk 31536000 {alg} {size} goal:omnipresent dnskey:rumoured zrrsig:hidden",
     ]
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
     expected = isctest.kasp.policy_to_properties(300, key_properties)
     keys = isctest.kasp.keydir_to_keylist(zone, "ns3")
     ksks = [k for k in keys if k.is_ksk()]
     zsks = [k for k in keys if not k.is_ksk()]
-    isctest.kasp.check_dnssec_verify(server, zone)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
     isctest.kasp.check_keys(zone, keys, expected)
 
     offset = -timedelta(days=30 * 6)
@@ -1526,7 +1551,7 @@ def test_kasp_zsk_retired(servers):
     expected[2].timing["ZRRSIGChange"] = None
 
     isctest.kasp.check_keytimes(keys, expected)
-    check_all(server, zone, policy, ksks, zsks)
+    check_all(ns3, zone, policy, ksks, zsks)
 
     queries = [
         f"{zone} DNSKEY",
@@ -1548,25 +1573,23 @@ def test_kasp_zsk_retired(servers):
         qname = parts[0]
         qtype = dns.rdatatype.from_text(parts[1])
         return isctest.kasp.verify_rrsig_is_refreshed(
-            server, zone, f"ns3/{zone}.db.signed", qname, qtype, ksks, zsks
+            ns3, zone, f"ns3/{zone}.db.signed", qname, qtype, ksks, zsks
         )
 
     for query in queries:
         isctest.run.retry_with_timeout(rrsig_is_refreshed, timeout=5)
 
     # Load again, make sure the purged key is not an issue when verifying keys.
-    with server.watch_log_from_here() as watcher:
-        server.rndc(f"loadkeys {zone}", log=False)
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"loadkeys {zone}", log=False)
         watcher.wait_for_line(f"keymgr: {zone} done")
 
     msg = f"zone {zone}/IN (signed): zone_rekey:zone_verifykeys failed: some key files are missing"
-    server.log.prohibit(msg)
+    ns3.log.prohibit(msg)
 
 
-def test_kasp_purge_keys(servers):
+def test_kasp_purge_keys(ns4):
     zone = "purgekeys.kasp"
-    server = servers["ns4"]
-
     tsig1 = (
         f"{os.environ['DEFAULT_HMAC']}:keyforview1:{KASP_INHERIT_TSIG_SECRET['view1']}"
     )
@@ -1574,34 +1597,35 @@ def test_kasp_purge_keys(servers):
         f"{os.environ['DEFAULT_HMAC']}:keyforview2:{KASP_INHERIT_TSIG_SECRET['view2']}"
     )
 
-    isctest.kasp.check_dnssec_verify(server, zone, tsig=tsig1)
-    isctest.kasp.check_dnssec_verify(server, zone, tsig=tsig2)
+    isctest.kasp.wait_keymgr_done(ns4, zone)
+
+    isctest.kasp.check_dnssec_verify(ns4, zone, tsig=tsig1)
+    isctest.kasp.check_dnssec_verify(ns4, zone, tsig=tsig2)
 
     # Reconfig, make sure the purged key is not an issue when verifying keys.
     shutil.copyfile("ns4/purgekeys2.conf", "ns4/purgekeys.conf")
-    with server.watch_log_from_here() as watcher:
-        server.rndc("reconfig", log=False)
+    with ns4.watch_log_from_here() as watcher:
+        ns4.rndc("reconfig", log=False)
         watcher.wait_for_line(f"keymgr: {zone} done")
 
     msg = f"zone {zone}/IN/example1 (signed): zone_rekey:zone_verifykeys failed: some key files are missing"
-    server.log.prohibit(msg)
+    ns4.log.prohibit(msg)
 
     msg = f"zone {zone}/IN/example2 (signed): zone_rekey:zone_verifykeys failed: some key files are missing"
-    server.log.prohibit(msg)
+    ns4.log.prohibit(msg)
 
 
-def test_kasp_reload_restart(servers):
-    server = servers["ns6"]
+def test_kasp_reload_restart(ns6):
     zone = "example"
 
     def query_soa(qname):
         fqdn = dns.name.from_text(qname)
         qtype = dns.rdatatype.SOA
-        query = dns.message.make_query(fqdn, qtype, use_edns=True, want_dnssec=True)
+        query = isctest.query.create(fqdn, qtype)
         try:
-            response = isctest.query.tcp(query, server.ip, server.ports.dns, timeout=3)
+            response = isctest.query.tcp(query, ns6.ip, ns6.ports.dns, timeout=3)
         except dns.exception.Timeout:
-            isctest.log.debug(f"query timeout for query {qname} SOA to {server.ip}")
+            isctest.log.debug(f"query timeout for query {qname} SOA to {ns6.ip}")
             return 0, 0
 
         assert response.rcode() == dns.rcode.NOERROR
@@ -1626,8 +1650,8 @@ def test_kasp_reload_restart(servers):
     assert ttl1 == 300
 
     shutil.copyfile(f"ns6/{zone}2.db.in", f"ns6/{zone}.db")
-    with server.watch_log_from_here() as watcher:
-        server.rndc("reload", log=False)
+    with ns6.watch_log_from_here() as watcher:
+        ns6.rndc("reload", log=False)
         watcher.wait_for_line("all zones loaded")
 
     newttl = 300
@@ -1638,12 +1662,111 @@ def test_kasp_reload_restart(servers):
     soa1, ttl1 = query_soa(zone)
     assert ttl1 == 300
 
-    server.stop()
+    ns6.stop()
     shutil.copyfile(f"ns6/{zone}3.db.in", f"ns6/{zone}.db")
     os.unlink(f"ns6/{zone}.db.jnl")
-    with server.watch_log_from_here() as watcher:
-        server.start(["--noclean", "--restart", "--port", os.environ["PORT"]])
+    with ns6.watch_log_from_here() as watcher:
+        ns6.start(["--noclean", "--restart", "--port", os.environ["PORT"]])
         watcher.wait_for_line("all zones loaded")
 
     newttl = 400
     isctest.run.retry_with_timeout(check_soa_ttl, timeout=10)
+
+
+def test_kasp_manual_mode(ns3):
+
+    keydir = ns3.identifier
+    zone = "keyfiles-missing.manual"
+    policy = "manual"
+    ttl = int(autosign_config["dnskey-ttl"].total_seconds())
+    offset = -timedelta(days=30 * 6)
+    alg = os.environ["DEFAULT_ALGORITHM_NUMBER"]
+    size = os.environ["DEFAULT_BITS"]
+    keyprops = [
+        f"ksk {lifetime['P2Y']} {alg} {size} goal:omnipresent dnskey:omnipresent krrsig:omnipresent ds:omnipresent",
+        f"zsk {lifetime['P2M']} {alg} {size} goal:omnipresent dnskey:omnipresent zrrsig:omnipresent",
+    ]
+
+    isctest.kasp.wait_keymgr_done(ns3, zone)
+
+    isctest.log.info(f"check test case zone {zone} policy {policy}")
+
+    # First make sure the zone is signed.
+    isctest.kasp.check_dnssec_verify(ns3, zone)
+
+    # Key properties.
+    expected = isctest.kasp.policy_to_properties(ttl=ttl, keys=keyprops)
+
+    # Key files.
+    keys = isctest.kasp.keydir_to_keylist(zone, keydir)
+    ksks = [k for k in keys if k.is_ksk()]
+    zsks = [k for k in keys if not k.is_ksk()]
+    isctest.kasp.check_dnssec_verify(ns3, zone)
+    isctest.kasp.check_keys(zone, keys, expected)
+
+    for kp in expected:
+        kp.set_expected_keytimes(autosign_config, offset=offset)
+
+    isctest.kasp.check_keytimes(keys, expected)
+
+    check_all(ns3, zone, policy, ksks, zsks, manual_mode=True)
+
+    # Key rollover should have been be blocked.
+    tag = expected[1].key.tag
+    blockmsg = f"keymgr-manual-mode: block ZSK rollover for key {zone}/ECDSAP256SHA256/{tag} (policy {policy})"
+    ns3.log.expect(blockmsg)
+
+    # Remove files.
+    for key in ksks + zsks:
+        shutil.copyfile(key.privatefile, f"{key.privatefile}.backup")
+        shutil.copyfile(key.keyfile, f"{key.keyfile}.backup")
+        shutil.copyfile(key.statefile, f"{key.statefile}.backup")
+
+        os.remove(key.keyfile)
+        os.remove(key.privatefile)
+        os.remove(key.statefile)
+
+    # Force step.
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"dnssec -step {zone}", log=False)
+        watcher.wait_for_line(
+            f"zone {zone}/IN (signed): zone_rekey:zone_verifykeys failed: some key files are missing"
+        )
+
+    # Restore key files.
+    for key in ksks + zsks:
+        shutil.copyfile(f"{key.privatefile}.backup", key.privatefile)
+        shutil.copyfile(f"{key.keyfile}.backup", key.keyfile)
+        shutil.copyfile(f"{key.statefile}.backup", key.statefile)
+
+    # Load keys.
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"loadkeys {zone}", log=False)
+        watcher.wait_for_line(blockmsg)
+
+    # Check keys again, make sure no new keys are created.
+    isctest.kasp.check_keys(zone, keys, expected)
+    isctest.kasp.check_keytimes(keys, expected)
+    check_all(ns3, zone, policy, ksks, zsks, manual_mode=True)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
+
+    # Force step.
+    with ns3.watch_log_from_here() as watcher:
+        ns3.rndc(f"dnssec -step {zone}", log=False)
+        watcher.wait_for_line(
+            f"zone {zone}/IN (signed): zone_rekey done: key {tag}/ECDSAP256SHA256"
+        )
+
+    # Check keys again, make sure the rollover has started.
+    keyprops = [
+        f"ksk {lifetime['P2Y']} {alg} {size} goal:omnipresent dnskey:omnipresent krrsig:omnipresent ds:omnipresent",
+        f"zsk {lifetime['P2M']} {alg} {size} goal:hidden dnskey:omnipresent zrrsig:omnipresent",
+        f"zsk {lifetime['P2M']} {alg} {size} goal:omnipresent dnskey:rumoured zrrsig:hidden",
+    ]
+    expected = isctest.kasp.policy_to_properties(ttl=ttl, keys=keyprops)
+    keys = isctest.kasp.keydir_to_keylist(zone, keydir)
+    ksks = [k for k in keys if k.is_ksk()]
+    zsks = [k for k in keys if not k.is_ksk()]
+    isctest.kasp.check_keys(zone, keys, expected)
+    check_all(ns3, zone, policy, ksks, zsks, manual_mode=True)
+    isctest.kasp.check_dnssec_verify(ns3, zone)
