@@ -11,10 +11,6 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-# Silence incorrect warnings cause by hypothesis.assume()
-# https://github.com/pylint-dev/pylint/issues/10785#issuecomment-3677224217
-# pylint: disable=unreachable
-
 from dataclasses import dataclass
 import os
 from pathlib import Path
@@ -22,6 +18,7 @@ from typing import Optional, Set, Tuple
 
 import pytest
 
+pytest.importorskip("dns", minversion="2.5.0")
 import dns.dnssec
 import dns.message
 import dns.name
@@ -44,12 +41,7 @@ AUTH = "10.53.0.1"
 RESOLVER = "10.53.0.2"
 TIMEOUT = 5
 ZONE = isctest.name.ZoneAnalyzer.read_path(
-    Path(os.environ["TOP_SRCDIR"])
-    / "bin"
-    / "tests"
-    / "system"
-    / "nsec3-answer/ns1/root.db.in",
-    origin=SUFFIX,
+    Path(os.environ["srcdir"]) / "nsec3-answer/ns1/root.db.in", origin=SUFFIX
 )
 
 
