@@ -9,6 +9,16 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
+import pytest
+
+pytestmark = pytest.mark.extra_artifacts(
+    [
+        "nslookup.err*",
+        "nslookup.out*",
+        "ns1/example.db",
+    ]
+)
+
 
 def test_nslookup(run_tests_sh):
     run_tests_sh()
