@@ -32,50 +32,21 @@ from rollover.common import (
     DURATION,
     TIMEDELTA,
 )
-from rollover.setup import (
-    configure_root,
-    configure_tld,
-    configure_algo_ksk_zsk,
-)
 
 CONFIG = ALGOROLL_CONFIG
 POLICY = "ecdsa256"
 TIME_PASSED = 0  # set in reconfigure() fixture
 
 
-def bootstrap():
-    data = {
-        "tlds": [],
-        "trust_anchors": [],
-    }
-
-    tlds = []
-    for tld_name in [
-        "kasp",
-        "manual",
-    ]:
-        delegations = configure_algo_ksk_zsk(tld_name, reconfig=True)
-
-        tld = configure_tld(tld_name, delegations)
-        tlds.append(tld)
-
-        data["tlds"].append(tld_name)
-
-    ta = configure_root(tlds)
-    data["trust_anchors"].append(ta)
-
-    return data
-
-
 @pytest.fixture(scope="module", autouse=True)
-def after_servers_start(ns3, templates):
+def reconfigure(ns6, templates):
     global TIME_PASSED  # pylint: disable=global-statement
 
-    isctest.kasp.wait_keymgr_done(ns3, "step1.algorithm-roll.kasp")
+    isctest.kasp.wait_keymgr_done(ns6, "step1.algorithm-roll.kasp")
 
-    templates.render("ns3/named.conf", {"alg_roll": True})
+    templates.render("ns6/named.conf", {"alg_roll": True})
     start_time = KeyTimingMetadata.now()
-    ns3.reconfigure()
+    ns6.reconfigure()
 
     # Calculate time passed to correctly check for next key events.
     TIME_PASSED = KeyTimingMetadata.now().value - start_time.value
@@ -88,11 +59,11 @@ def after_servers_start(ns3, templates):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step1(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step1(tld, ns6, alg, size):
     zone = f"step1.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     if tld == "manual":
         # Same as initial.
@@ -106,7 +77,7 @@ def test_algoroll_ksk_zsk_reconfig_step1(tld, ns3, alg, size):
             "manual-mode": True,
             "nextev": None,
         }
-        keys = isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
+        keys = isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
         # Check logs.
         ktag = keys[0].key.tag
@@ -114,13 +85,13 @@ def test_algoroll_ksk_zsk_reconfig_step1(tld, ns3, alg, size):
         msg1 = f"keymgr-manual-mode: block retire DNSKEY {zone}/RSASHA256/{ktag} (KSK)"
         msg2 = f"keymgr-manual-mode: block retire DNSKEY {zone}/RSASHA256/{ztag} (ZSK)"
         msg3 = f"keymgr-manual-mode: block new key generation for zone {zone} (policy {policy})"  # twice
-        assert msg1 in ns3.log
-        assert msg2 in ns3.log
-        assert len(ns3.log.grep(msg3)) == 2
+        ns6.log.expect(msg1)
+        ns6.log.expect(msg2)
+        ns6.log.expect(msg3)
 
         # Force step.
-        with ns3.watch_log_from_here() as watcher:
-            ns3.rndc(f"dnssec -step {zone}")
+        with ns6.watch_log_from_here() as watcher:
+            ns6.rndc(f"dnssec -step {zone}")
             watcher.wait_for_line(
                 f"zone {zone}/IN (signed): zone_rekey done: key {ktag}/RSASHA256"
             )
@@ -139,9 +110,7 @@ def test_algoroll_ksk_zsk_reconfig_step1(tld, ns3, alg, size):
         # Next key event is when the ecdsa256 keys have been propagated.
         "nextev": ALGOROLL_IPUB,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    assert f"zone {zone}/IN (signed): dsyncfetch" not in ns3.log
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
 
 @pytest.mark.parametrize(
@@ -151,11 +120,11 @@ def test_algoroll_ksk_zsk_reconfig_step1(tld, ns3, alg, size):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step2(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step2(tld, ns6, alg, size):
     zone = f"step2.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     # manual-mode: Nothing changing in the zone, no 'dnssec -step' required.
 
@@ -180,9 +149,7 @@ def test_algoroll_ksk_zsk_reconfig_step2(tld, ns3, alg, size):
         # key creation and invoking 'rndc reconfig'.
         "nextev": ALGOROLL_IPUBC - ALGOROLL_IPUB - TIME_PASSED,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    assert f"zone {zone}/IN (signed): dsyncfetch" not in ns3.log
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
 
 @pytest.mark.parametrize(
@@ -192,11 +159,11 @@ def test_algoroll_ksk_zsk_reconfig_step2(tld, ns3, alg, size):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step3(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step3(tld, ns6, alg, size):
     zone = f"step3.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     if tld == "manual":
         # Same as step 2, but the zone signatures have become OMNIPRESENT.
@@ -212,16 +179,16 @@ def test_algoroll_ksk_zsk_reconfig_step3(tld, ns3, alg, size):
             "manual-mode": True,
             "nextev": None,
         }
-        keys = isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
+        keys = isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
         # Check logs.
         tag = keys[2].key.tag
         msg = f"keymgr-manual-mode: block transition KSK {zone}/ECDSAP256SHA256/{tag} type DS state HIDDEN to state RUMOURED"
-        assert msg in ns3.log
+        ns6.log.expect(msg)
 
         # Force step.
-        with ns3.watch_log_from_here() as watcher:
-            ns3.rndc(f"dnssec -step {zone}")
+        with ns6.watch_log_from_here() as watcher:
+            ns6.rndc(f"dnssec -step {zone}")
             watcher.wait_for_line(
                 f"zone {zone}/IN (signed): zone_rekey done: key {tag}/ECDSAP256SHA256"
             )
@@ -229,14 +196,14 @@ def test_algoroll_ksk_zsk_reconfig_step3(tld, ns3, alg, size):
         # Check logs.
         tag = keys[0].key.tag
         msg = f"keymgr-manual-mode: block transition KSK {zone}/RSASHA256/{tag} type DS state OMNIPRESENT to state UNRETENTIVE"
-        if msg in ns3.log:
+        if msg in ns6.log:
             # Force step.
             isctest.log.debug(
                 f"keymgr-manual-mode blocking transition CSK {zone}/RSASHA256/{tag} type DS state OMNIPRESENT to state UNRETENTIVE, step again"
             )
             tag = keys[2].key.tag
-            with ns3.watch_log_from_here() as watcher:
-                ns3.rndc(f"dnssec -step {zone}")
+            with ns6.watch_log_from_here() as watcher:
+                ns6.rndc(f"dnssec -step {zone}")
                 watcher.wait_for_line(
                     f"zone {zone}/IN (signed): zone_rekey done: key {tag}/ECDSAP256SHA256"
                 )
@@ -255,12 +222,7 @@ def test_algoroll_ksk_zsk_reconfig_step3(tld, ns3, alg, size):
         # after the retire interval.
         "nextev": ALGOROLL_IRETKSK - TIME_PASSED,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    with ns3.watch_log_from_start() as watcher:
-        watcher.wait_for_line(
-            f"zone {zone}/IN (signed): dsyncfetch: send NOTIFY(CDS) query to scanner.{tld}"
-        )
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
 
 @pytest.mark.parametrize(
@@ -270,11 +232,11 @@ def test_algoroll_ksk_zsk_reconfig_step3(tld, ns3, alg, size):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step4(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step4(tld, ns6, alg, size):
     zone = f"step4.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     if tld == "manual":
         # Same as step 3, but the DS has become HIDDEN/OMNIPRESENT.
@@ -290,20 +252,20 @@ def test_algoroll_ksk_zsk_reconfig_step4(tld, ns3, alg, size):
             "manual-mode": True,
             "nextev": None,
         }
-        keys = isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
+        keys = isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
         # Check logs.
         ktag = keys[0].key.tag
         ztag = keys[1].key.tag
         msg1 = f"keymgr-manual-mode: block transition KSK {zone}/RSASHA256/{ktag} type DNSKEY state OMNIPRESENT to state UNRETENTIVE"
         msg2 = f"keymgr-manual-mode: block transition ZSK {zone}/RSASHA256/{ztag} type DNSKEY state OMNIPRESENT to state UNRETENTIVE"
-        assert msg1 in ns3.log
-        assert msg2 in ns3.log
+        ns6.log.expect(msg1)
+        ns6.log.expect(msg2)
 
         # Force step.
         ktag = keys[3].key.tag
-        with ns3.watch_log_from_here() as watcher:
-            ns3.rndc(f"dnssec -step {zone}")
+        with ns6.watch_log_from_here() as watcher:
+            ns6.rndc(f"dnssec -step {zone}")
             watcher.wait_for_line(
                 f"zone {zone}/IN (signed): zone_rekey done: key {ktag}/ECDSAP256SHA256"
             )
@@ -322,9 +284,7 @@ def test_algoroll_ksk_zsk_reconfig_step4(tld, ns3, alg, size):
         # This happens after the DNSKEY TTL plus zone propagation delay.
         "nextev": ALGOROLL_KEYTTLPROP,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    assert f"zone {zone}/IN (signed): dsyncfetch" not in ns3.log
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
 
 @pytest.mark.parametrize(
@@ -334,11 +294,11 @@ def test_algoroll_ksk_zsk_reconfig_step4(tld, ns3, alg, size):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step5(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step5(tld, ns6, alg, size):
     zone = f"step5.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     # manual-mode: Nothing changing in the zone, no 'dnssec -step' required.
 
@@ -359,12 +319,8 @@ def test_algoroll_ksk_zsk_reconfig_step5(tld, ns3, alg, size):
         # platforms by subtracting the number of seconds which passed
         # between key creation and invoking 'rndc reconfig'.
         "nextev": ALGOROLL_IRET - ALGOROLL_IRETKSK - ALGOROLL_KEYTTLPROP - TIME_PASSED,
-        # Include hidden keys in output.
-        "verbose": True,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    assert f"zone {zone}/IN (signed): dsyncfetch" not in ns3.log
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
 
 
 @pytest.mark.parametrize(
@@ -374,11 +330,11 @@ def test_algoroll_ksk_zsk_reconfig_step5(tld, ns3, alg, size):
         param("manual"),
     ],
 )
-def test_algoroll_ksk_zsk_reconfig_step6(tld, ns3, alg, size):
+def test_algoroll_ksk_zsk_reconfig_step6(tld, ns6, alg, size):
     zone = f"step6.algorithm-roll.{tld}"
     policy = f"{POLICY}-{tld}"
 
-    isctest.kasp.wait_keymgr_done(ns3, zone, reconfig=True)
+    isctest.kasp.wait_keymgr_done(ns6, zone, reconfig=True)
 
     # manual-mode: Nothing changing in the zone, no 'dnssec -step' required.
 
@@ -396,9 +352,5 @@ def test_algoroll_ksk_zsk_reconfig_step6(tld, ns3, alg, size):
         # keys have an unlimited lifetime.  Fallback to the default
         # loadkeys interval.
         "nextev": TIMEDELTA["PT1H"],
-        # Include hidden keys in output.
-        "verbose": True,
     }
-    isctest.kasp.check_rollover_step(ns3, CONFIG, policy, step)
-
-    assert f"zone {zone}/IN (signed): dsyncfetch" not in ns3.log
+    isctest.kasp.check_rollover_step(ns6, CONFIG, policy, step)
