@@ -15,11 +15,13 @@ import os
 
 import pytest
 
-import dns
+pytest.importorskip("dns", minversion="2.0.0")
 import dns.rcode
 import dns.rrset
 
 import isctest
+from isctest.compat import dns_rcode
+
 
 pytestmark = pytest.mark.extra_artifacts(
     [
@@ -76,13 +78,13 @@ def test_rpz_multiple_views(qname, source, rcode):
         msg,
         ip="10.53.0.3",
         source="10.53.0.2",
-        expected_rcode=dns.rcode.NOERROR,
+        expected_rcode=dns_rcode.NOERROR,
     )
     isctest.query.tcp(
         msg,
         ip="10.53.0.3",
         source="10.53.0.5",
-        expected_rcode=dns.rcode.NOERROR,
+        expected_rcode=dns_rcode.NOERROR,
     )
 
     msg = isctest.query.create(qname, "A")
@@ -103,6 +105,23 @@ def test_rpz_passthru_logging():
         dns.rrset.from_text("allowed.", 300, "IN", "A", "10.53.0.2")
     ]
 
+    # Should also generate a log entry into rpz_passthru.txt
+    msg_allowed_any = isctest.query.create("allowed.", "ANY")
+    res_allowed_any = isctest.query.udp(
+        msg_allowed_any,
+        resolver_ip,
+        source="10.53.0.1",
+        expected_rcode=dns.rcode.NOERROR,
+    )
+    assert res_allowed_any.answer == [
+        dns.rrset.from_text("allowed.", 300, "IN", "NS", "ns1.allowed."),
+        dns.rrset.from_text("allowed.", 300, "IN", "A", "10.53.0.2"),
+    ]
+    # The comparison above doesn't compare the TTL values, and we want to
+    # make sure that the "passthru" rpz doesn't cap the TTL with max-policy-ttl.
+    assert res_allowed_any.answer[0].ttl > 200
+    assert res_allowed_any.answer[1].ttl > 200
+
     # baddomain.com isn't allowed (CNAME .), should return NXDOMAIN
     # Should generate a log entry into rpz.txt
     msg_not_allowed = isctest.query.create("baddomain.", "A")
