@@ -38,7 +38,7 @@ LLVMFuzzerTestOneInput(const uint8_t *data, size_t size);
 
 #define CHECK(x)                    \
 	if ((x) != ISC_R_SUCCESS) { \
-		return 0;           \
+		return (0);         \
 	}
 
 ISC_LANG_ENDDECLS
