@@ -27,22 +27,22 @@ extern isc_logmodule_t	 dns_modules[];
 #define DNS_LOGCATEGORY_DATABASE (&dns_categories[1])
 #define DNS_LOGCATEGORY_SECURITY (&dns_categories[2])
 /* DNS_LOGCATEGORY_CONFIG superseded by CFG_LOGCATEGORY_CONFIG */
-#define DNS_LOGCATEGORY_DNSSEC		(&dns_categories[4])
-#define DNS_LOGCATEGORY_RESOLVER	(&dns_categories[5])
-#define DNS_LOGCATEGORY_XFER_IN		(&dns_categories[6])
-#define DNS_LOGCATEGORY_XFER_OUT	(&dns_categories[7])
-#define DNS_LOGCATEGORY_DISPATCH	(&dns_categories[8])
-#define DNS_LOGCATEGORY_LAME_SERVERS	(&dns_categories[9])
-#define DNS_LOGCATEGORY_DELEGATION_ONLY (&dns_categories[10])
-#define DNS_LOGCATEGORY_EDNS_DISABLED	(&dns_categories[11])
-#define DNS_LOGCATEGORY_RPZ		(&dns_categories[12])
-#define DNS_LOGCATEGORY_RRL		(&dns_categories[13])
-#define DNS_LOGCATEGORY_CNAME		(&dns_categories[14])
-#define DNS_LOGCATEGORY_SPILL		(&dns_categories[15])
-#define DNS_LOGCATEGORY_DNSTAP		(&dns_categories[16])
-#define DNS_LOGCATEGORY_ZONELOAD	(&dns_categories[17])
-#define DNS_LOGCATEGORY_NSID		(&dns_categories[18])
-#define DNS_LOGCATEGORY_RPZ_PASSTHRU	(&dns_categories[19])
+#define DNS_LOGCATEGORY_DNSSEC	     (&dns_categories[4])
+#define DNS_LOGCATEGORY_RESOLVER     (&dns_categories[5])
+#define DNS_LOGCATEGORY_XFER_IN	     (&dns_categories[6])
+#define DNS_LOGCATEGORY_XFER_OUT     (&dns_categories[7])
+#define DNS_LOGCATEGORY_DISPATCH     (&dns_categories[8])
+#define DNS_LOGCATEGORY_LAME_SERVERS (&dns_categories[9])
+/* #define DNS_LOGCATEGORY_DELEGATION_ONLY removed */
+#define DNS_LOGCATEGORY_EDNS_DISABLED (&dns_categories[10])
+#define DNS_LOGCATEGORY_RPZ	      (&dns_categories[11])
+#define DNS_LOGCATEGORY_RRL	      (&dns_categories[12])
+#define DNS_LOGCATEGORY_CNAME	      (&dns_categories[13])
+#define DNS_LOGCATEGORY_SPILL	      (&dns_categories[14])
+#define DNS_LOGCATEGORY_DNSTAP	      (&dns_categories[15])
+#define DNS_LOGCATEGORY_ZONELOAD      (&dns_categories[16])
+#define DNS_LOGCATEGORY_NSID	      (&dns_categories[17])
+#define DNS_LOGCATEGORY_RPZ_PASSTHRU  (&dns_categories[18])
 
 /* Backwards compatibility. */
 #define DNS_LOGCATEGORY_GENERAL ISC_LOGCATEGORY_GENERAL
