@@ -49,7 +49,7 @@
 #include "qp_p.h"
 
 #ifndef DNS_QP_LOG_STATS
-#define DNS_QP_LOG_STATS 1
+#define DNS_QP_LOG_STATS 0
 #endif
 #ifndef DNS_QP_TRACE
 #define DNS_QP_TRACE 0
@@ -96,6 +96,19 @@ static atomic_uint_fast64_t rollback_time;
 #define TRACE(...)
 #endif
 
+#if DNS_QPMULTI_TRACE
+ISC_REFCOUNT_STATIC_TRACE_DECL(dns_qpmulti);
+#define dns_qpmulti_ref(ptr) dns_qpmulti__ref(ptr, __func__, __FILE__, __LINE__)
+#define dns_qpmulti_unref(ptr) \
+	dns_qpmulti__unref(ptr, __func__, __FILE__, __LINE__)
+#define dns_qpmulti_attach(ptr, ptrp) \
+	dns_qpmulti__attach(ptr, ptrp, __func__, __FILE__, __LINE__)
+#define dns_qpmulti_detach(ptrp) \
+	dns_qpmulti__detach(ptrp, __func__, __FILE__, __LINE__)
+#else
+ISC_REFCOUNT_STATIC_DECL(dns_qpmulti);
+#endif
+
 /***********************************************************************
  *
  *  converting DNS names to trie keys
@@ -219,7 +232,7 @@ dns_qpkey_fromname(dns_qpkey_t key, const dns_name_t *name) {
 
 	if (name->labels == 0) {
 		key[0] = SHIFT_NOBYTE;
-		return (0);
+		return 0;
 	}
 
 	if (name->offsets == NULL) {
@@ -246,7 +259,7 @@ dns_qpkey_fromname(dns_qpkey_t key, const dns_name_t *name) {
 	/* mark end with a double NOBYTE */
 	key[len] = SHIFT_NOBYTE;
 	ENSURE(len < sizeof(dns_qpkey_t));
-	return (len);
+	return len;
 }
 
 void
@@ -353,10 +366,10 @@ qpkey_compare(const dns_qpkey_t key_a, const size_t keylen_a,
 		if (qpkey_bit(key_a, keylen_a, offset) !=
 		    qpkey_bit(key_b, keylen_b, offset))
 		{
-			return (offset);
+			return offset;
 		}
 	}
-	return (QPKEY_EQUAL);
+	return QPKEY_EQUAL;
 }
 
 /***********************************************************************
@@ -377,7 +390,7 @@ qpkey_compare(const dns_qpkey_t key_a, const size_t keylen_a,
 static size_t
 chunk_size_raw(void) {
 	size_t size = (size_t)sysconf(_SC_PAGE_SIZE);
-	return (ISC_MAX(size, QP_CHUNK_BYTES));
+	return ISC_MAX(size, QP_CHUNK_BYTES);
 }
 
 static void *
@@ -387,9 +400,9 @@ chunk_get_raw(dns_qp_t *qp) {
 		void *ptr = mmap(NULL, size, PROT_READ | PROT_WRITE,
 				 MAP_ANON | MAP_PRIVATE, -1, 0);
 		RUNTIME_CHECK(ptr != MAP_FAILED);
-		return (ptr);
+		return ptr;
 	} else {
-		return (isc_mem_allocate(qp->mctx, QP_CHUNK_BYTES));
+		return isc_mem_allocate(qp->mctx, QP_CHUNK_BYTES);
 	}
 }
 
@@ -405,9 +418,9 @@ chunk_free_raw(dns_qp_t *qp, void *ptr) {
 static void *
 chunk_shrink_raw(dns_qp_t *qp, void *ptr, size_t bytes) {
 	if (qp->write_protect) {
-		return (ptr);
+		return ptr;
 	} else {
-		return (isc_mem_reallocate(qp->mctx, ptr, bytes));
+		return isc_mem_reallocate(qp->mctx, ptr, bytes);
 	}
 }
 
@@ -427,7 +440,7 @@ write_protect(dns_qp_t *qp, dns_qpchunk_t chunk) {
 
 #else
 
-#define chunk_get_raw(qp)	isc_mem_allocate(qp->mctx, QP_CHUNK_BYTES)
+#define chunk_get_raw(qp, size) isc_mem_allocate(qp->mctx, size)
 #define chunk_free_raw(qp, ptr) isc_mem_free(qp->mctx, ptr)
 
 #define chunk_shrink_raw(qp, ptr, size) isc_mem_reallocate(qp->mctx, ptr, size)
@@ -450,12 +463,28 @@ cells_immutable(dns_qp_t *qp, dns_qpref_t ref) {
 	dns_qpchunk_t chunk = ref_chunk(ref);
 	dns_qpcell_t cell = ref_cell(ref);
 	if (chunk == qp->bump) {
-		return (cell < qp->fender);
+		return cell < qp->fender;
 	} else {
-		return (qp->usage[chunk].immutable);
+		return qp->usage[chunk].immutable;
 	}
 }
 
+/*
+ * Find the next power that is both bigger than size and prev_capacity,
+ * but still within the chunk min and max sizes.
+ */
+static dns_qpcell_t
+next_capacity(uint32_t prev_capacity, uint32_t size) {
+	/*
+	 * Unfortunately builtin_clz is undefined for 0. We work around this
+	 * issue by flooring the request size at 2.
+	 */
+	size = ISC_MAX3(size, prev_capacity, 2u);
+	uint32_t log2 = 32u - __builtin_clz(size - 1u);
+
+	return 1U << ISC_CLAMP(log2, QP_CHUNK_LOG_MIN, QP_CHUNK_LOG_MAX);
+}
+
 /*
  * Create a fresh bump chunk and allocate some twigs from it.
  */
@@ -464,9 +493,15 @@ chunk_alloc(dns_qp_t *qp, dns_qpchunk_t chunk, dns_qpweight_t size) {
 	INSIST(qp->base->ptr[chunk] == NULL);
 	INSIST(qp->usage[chunk].used == 0);
 	INSIST(qp->usage[chunk].free == 0);
+	INSIST(qp->chunk_capacity <= QP_CHUNK_SIZE);
 
-	qp->base->ptr[chunk] = chunk_get_raw(qp);
-	qp->usage[chunk] = (qp_usage_t){ .exists = true, .used = size };
+	qp->chunk_capacity = next_capacity(qp->chunk_capacity * 2u, size);
+	qp->base->ptr[chunk] =
+		chunk_get_raw(qp, qp->chunk_capacity * sizeof(dns_qpnode_t));
+
+	qp->usage[chunk] = (qp_usage_t){ .exists = true,
+					 .used = size,
+					 .capacity = qp->chunk_capacity };
 	qp->used_count += size;
 	qp->bump = chunk;
 	qp->fender = 0;
@@ -474,7 +509,7 @@ chunk_alloc(dns_qp_t *qp, dns_qpchunk_t chunk, dns_qpweight_t size) {
 	if (qp->write_protect) {
 		TRACE("chunk %u base %p", chunk, qp->base->ptr[chunk]);
 	}
-	return (make_ref(chunk, 0));
+	return make_ref(chunk, 0);
 }
 
 /*
@@ -522,12 +557,12 @@ alloc_slow(dns_qp_t *qp, dns_qpweight_t size) {
 
 	for (chunk = 0; chunk < qp->chunk_max; chunk++) {
 		if (!qp->usage[chunk].exists) {
-			return (chunk_alloc(qp, chunk, size));
+			return chunk_alloc(qp, chunk, size);
 		}
 	}
 	ENSURE(chunk == qp->chunk_max);
 	realloc_chunk_arrays(qp, GROWTH_FACTOR(chunk));
-	return (chunk_alloc(qp, chunk, size));
+	return chunk_alloc(qp, chunk, size);
 }
 
 /*
@@ -546,12 +581,12 @@ alloc_twigs(dns_qp_t *qp, dns_qpweight_t size) {
 	dns_qpchunk_t chunk = qp->bump;
 	dns_qpcell_t cell = qp->usage[chunk].used;
 
-	if (cell + size <= QP_CHUNK_SIZE) {
+	if (cell + size <= qp->usage[chunk].capacity) {
 		qp->usage[chunk].used += size;
 		qp->used_count += size;
-		return (make_ref(chunk, cell));
+		return make_ref(chunk, cell);
 	} else {
-		return (alloc_slow(qp, size));
+		return alloc_slow(qp, size);
 	}
 }
 
@@ -577,10 +612,10 @@ free_twigs(dns_qp_t *qp, dns_qpref_t twigs, dns_qpweight_t size) {
 	if (cells_immutable(qp, twigs)) {
 		qp->hold_count += size;
 		ENSURE(qp->free_count >= qp->hold_count);
-		return (false);
+		return false;
 	} else {
 		zero_twigs(ref_ptr(qp, twigs), size);
-		return (true);
+		return true;
 	}
 }
 
@@ -608,7 +643,7 @@ attach_twigs(dns_qp_t *qp, dns_qpnode_t *twigs, dns_qpweight_t size) {
  */
 static inline dns_qpcell_t
 chunk_usage(dns_qp_t *qp, dns_qpchunk_t chunk) {
-	return (qp->usage[chunk].used - qp->usage[chunk].free);
+	return qp->usage[chunk].used - qp->usage[chunk].free;
 }
 
 /*
@@ -664,7 +699,7 @@ chunk_free(dns_qp_t *qp, dns_qpchunk_t chunk) {
  */
 static void
 recycle(dns_qp_t *qp) {
-	unsigned int free = 0;
+	unsigned int nfree = 0;
 
 	isc_nanosecs_t start = isc_time_monotonic();
 
@@ -673,15 +708,15 @@ recycle(dns_qp_t *qp) {
 		    qp->usage[chunk].exists && !qp->usage[chunk].immutable)
 		{
 			chunk_free(qp, chunk);
-			free++;
+			nfree++;
 		}
 	}
 
 	isc_nanosecs_t time = isc_time_monotonic() - start;
 	atomic_fetch_add_relaxed(&recycle_time, time);
 
-	if (free > 0) {
-		LOG_STATS("qp recycle" PRItime "free %u chunks", time, free);
+	if (nfree > 0) {
+		LOG_STATS("qp recycle" PRItime "free %u chunks", time, nfree);
 		LOG_STATS("qp recycle leaf %u live %u used %u free %u hold %u",
 			  qp->leaf_count, qp->used_count - qp->free_count,
 			  qp->used_count, qp->free_count, qp->hold_count);
@@ -699,38 +734,47 @@ reclaim_chunks_cb(struct rcu_head *arg) {
 	REQUIRE(QPMULTI_VALID(multi));
 
 	LOCK(&multi->mutex);
-
 	dns_qp_t *qp = &multi->writer;
-	REQUIRE(QP_VALID(qp));
 
-	unsigned int free = 0;
-	isc_nanosecs_t start = isc_time_monotonic();
+	/*
+	 * If chunk_max is zero, chunks have already been freed.
+	 */
+	if (qp->chunk_max != 0) {
+		unsigned int free = 0;
+		isc_nanosecs_t start = isc_time_monotonic();
 
-	for (unsigned int i = 0; i < rcuctx->count; i++) {
-		dns_qpchunk_t chunk = rcuctx->chunk[i];
-		if (qp->usage[chunk].snapshot) {
-			/* cleanup when snapshot is destroyed */
-			qp->usage[chunk].snapfree = true;
-		} else {
-			chunk_free(qp, chunk);
-			free++;
+		INSIST(QP_VALID(qp));
+
+		for (unsigned int i = 0; i < rcuctx->count; i++) {
+			dns_qpchunk_t chunk = rcuctx->chunk[i];
+			if (qp->usage[chunk].snapshot) {
+				/* clean up when snapshot is destroyed */
+				qp->usage[chunk].snapfree = true;
+			} else {
+				chunk_free(qp, chunk);
+				free++;
+			}
+		}
+
+		isc_nanosecs_t time = isc_time_monotonic() - start;
+		recycle_time += time;
+
+		if (free > 0) {
+			LOG_STATS("qp reclaim" PRItime "free %u chunks", time,
+				  free);
+			LOG_STATS(
+				"qp reclaim leaf %u live %u used %u free %u "
+				"hold %u",
+				qp->leaf_count, qp->used_count - qp->free_count,
+				qp->used_count, qp->free_count, qp->hold_count);
 		}
 	}
 
+	UNLOCK(&multi->mutex);
+
+	dns_qpmulti_detach(&multi);
 	isc_mem_putanddetach(&rcuctx->mctx, rcuctx,
 			     STRUCT_FLEX_SIZE(rcuctx, chunk, rcuctx->count));
-
-	isc_nanosecs_t time = isc_time_monotonic() - start;
-	recycle_time += time;
-
-	if (free > 0) {
-		LOG_STATS("qp reclaim" PRItime "free %u chunks", time, free);
-		LOG_STATS("qp reclaim leaf %u live %u used %u free %u hold %u",
-			  qp->leaf_count, qp->used_count - qp->free_count,
-			  qp->used_count, qp->free_count, qp->hold_count);
-	}
-
-	UNLOCK(&multi->mutex);
 }
 
 /*
@@ -775,6 +819,11 @@ reclaim_chunks(dns_qpmulti_t *multi) {
 		}
 	}
 
+	/*
+	 * Reference the qpmulti object to keep it from being
+	 * freed until reclaim_chunks_cb() runs.
+	 */
+	dns_qpmulti_ref(multi);
 	call_rcu(&rcuctx->rcu_head, reclaim_chunks_cb);
 
 	LOG_STATS("qp will reclaim %u chunks", count);
@@ -786,7 +835,7 @@ reclaim_chunks(dns_qpmulti_t *multi) {
  */
 static void
 marksweep_chunks(dns_qpmulti_t *multi) {
-	unsigned int free = 0;
+	unsigned int nfree = 0;
 
 	isc_nanosecs_t start = isc_time_monotonic();
 
@@ -809,15 +858,15 @@ marksweep_chunks(dns_qpmulti_t *multi) {
 		qpw->usage[chunk].snapmark = false;
 		if (qpw->usage[chunk].snapfree && !qpw->usage[chunk].snapshot) {
 			chunk_free(qpw, chunk);
-			free++;
+			nfree++;
 		}
 	}
 
 	isc_nanosecs_t time = isc_time_monotonic() - start;
 	recycle_time += time;
 
-	if (free > 0) {
-		LOG_STATS("qp marksweep" PRItime "free %u chunks", time, free);
+	if (nfree > 0) {
+		LOG_STATS("qp marksweep" PRItime "free %u chunks", time, nfree);
 		LOG_STATS(
 			"qp marksweep leaf %u live %u used %u free %u hold %u",
 			qpw->leaf_count, qpw->used_count - qpw->free_count,
@@ -852,7 +901,7 @@ evacuate(dns_qp_t *qp, dns_qpnode_t *n) {
 		attach_twigs(qp, new_twigs, size);
 	}
 
-	return (new_ref);
+	return new_ref;
 }
 
 /*
@@ -867,7 +916,7 @@ make_root_mutable(dns_qp_t *qp) {
 	if (cells_immutable(qp, qp->root_ref)) {
 		qp->root_ref = evacuate(qp, MOVABLE_ROOT(qp));
 	}
-	return (ref_ptr(qp, qp->root_ref));
+	return ref_ptr(qp, qp->root_ref);
 }
 
 static inline void
@@ -922,7 +971,7 @@ compact_recursive(dns_qp_t *qp, dns_qpnode_t *parent) {
 		}
 		*child = make_node(branch_index(child), new_grandtwigs);
 	}
-	return (twigs_ref);
+	return twigs_ref;
 }
 
 static void
@@ -1007,7 +1056,7 @@ squash_twigs(dns_qp_t *qp, dns_qpref_t twigs, dns_qpweight_t size) {
 			qp->compact_all = true;
 		}
 	}
-	return (destroyed);
+	return destroyed;
 }
 
 /***********************************************************************
@@ -1027,12 +1076,13 @@ dns_qp_memusage(dns_qp_t *qp) {
 		.hold = qp->hold_count,
 		.free = qp->free_count,
 		.node_size = sizeof(dns_qpnode_t),
-		.chunk_size = QP_CHUNK_SIZE,
 		.fragmented = QP_NEEDGC(qp),
 	};
 
+	size_t chunk_usage_bytes = 0;
 	for (dns_qpchunk_t chunk = 0; chunk < qp->chunk_max; chunk++) {
 		if (qp->base->ptr[chunk] != NULL) {
+			chunk_usage_bytes += qp->usage[chunk].capacity;
 			memusage.chunk_count += 1;
 		}
 	}
@@ -1041,11 +1091,11 @@ dns_qp_memusage(dns_qp_t *qp) {
 	 * XXXFANF does not subtract chunks that have been shrunk,
 	 * and does not count unreclaimed dns_qpbase_t objects
 	 */
-	memusage.bytes = memusage.chunk_count * QP_CHUNK_BYTES +
+	memusage.bytes = chunk_usage_bytes +
 			 qp->chunk_max * sizeof(qp->base->ptr[0]) +
 			 qp->chunk_max * sizeof(qp->usage[0]);
 
-	return (memusage);
+	return memusage;
 }
 
 dns_qp_memusage_t
@@ -1059,13 +1109,13 @@ dns_qpmulti_memusage(dns_qpmulti_t *multi) {
 	dns_qp_memusage_t memusage = dns_qp_memusage(qp);
 
 	if (qp->transaction_mode == QP_UPDATE) {
-		memusage.bytes -= QP_CHUNK_BYTES;
+		memusage.bytes -= qp->usage[qp->bump].capacity;
 		memusage.bytes += qp->usage[qp->bump].used *
 				  sizeof(dns_qpnode_t);
 	}
 
 	UNLOCK(&multi->mutex);
-	return (memusage);
+	return memusage;
 }
 
 void
@@ -1114,7 +1164,7 @@ transaction_open(dns_qpmulti_t *multi, dns_qp_t **qptp) {
 	qp->hold_count = qp->free_count;
 
 	*qptp = qp;
-	return (qp);
+	return qp;
 }
 
 /*
@@ -1254,7 +1304,10 @@ dns_qpmulti_commit(dns_qpmulti_t *multi, dns_qp_t **qptp) {
  */
 void
 dns_qpmulti_rollback(dns_qpmulti_t *multi, dns_qp_t **qptp) {
-	unsigned int free = 0;
+	/*
+	 * nfree is only used when logging stats, hence the attribute.
+	 */
+	unsigned int nfree ISC_ATTR_UNUSED = 0;
 
 	REQUIRE(QPMULTI_VALID(multi));
 	REQUIRE(multi->writer.transaction_mode == QP_UPDATE);
@@ -1277,7 +1330,7 @@ dns_qpmulti_rollback(dns_qpmulti_t *multi, dns_qp_t **qptp) {
 				INSIST(!multi->rollback->usage[chunk].exists);
 				multi->rollback->base->ptr[chunk] = NULL;
 			}
-			free++;
+			nfree++;
 		}
 	}
 
@@ -1300,7 +1353,7 @@ dns_qpmulti_rollback(dns_qpmulti_t *multi, dns_qp_t **qptp) {
 	isc_nanosecs_t time = isc_time_monotonic() - start;
 	atomic_fetch_add_relaxed(&rollback_time, time);
 
-	LOG_STATS("qp rollback" PRItime "free %u chunks", time, free);
+	LOG_STATS("qp rollback" PRItime "free %u chunks", time, nfree);
 
 	*qptp = NULL;
 	UNLOCK(&multi->mutex);
@@ -1320,7 +1373,7 @@ reader_open(dns_qpmulti_t *multi, dns_qpreadable_t qpr) {
 	} else {
 		multi = unpack_reader(qp, reader);
 	}
-	return (multi);
+	return multi;
 }
 
 /*
@@ -1444,12 +1497,12 @@ dns_qpmulti_create(isc_mem_t *mctx, const dns_qpmethods_t *methods, void *uctx,
 	REQUIRE(qpmp != NULL && *qpmp == NULL);
 
 	dns_qpmulti_t *multi = isc_mem_get(mctx, sizeof(*multi));
-	*multi = (dns_qpmulti_t){
-		.magic = QPMULTI_MAGIC,
-		.reader_ref = INVALID_REF,
-	};
+	*multi = (dns_qpmulti_t){ .magic = QPMULTI_MAGIC,
+				  .reader_ref = INVALID_REF,
+				  .references = ISC_REFCOUNT_INITIALIZER(1) };
 	isc_mutex_init(&multi->mutex);
 	ISC_LIST_INIT(multi->snapshots);
+
 	/*
 	 * Do not waste effort allocating a bump chunk that will be thrown
 	 * away when a transaction is opened. dns_qpmulti_update() always
@@ -1469,11 +1522,13 @@ destroy_guts(dns_qp_t *qp) {
 	if (qp->chunk_max == 0) {
 		return;
 	}
+
 	for (dns_qpchunk_t chunk = 0; chunk < qp->chunk_max; chunk++) {
 		if (qp->base->ptr[chunk] != NULL) {
 			chunk_free(qp, chunk);
 		}
 	}
+	qp->chunk_max = 0;
 	ENSURE(qp->used_count == 0);
 	ENSURE(qp->free_count == 0);
 	ENSURE(isc_refcount_current(&qp->base->refcount) == 1);
@@ -1499,7 +1554,26 @@ dns_qp_destroy(dns_qp_t **qptp) {
 }
 
 static void
-qpmulti_destroy_cb(struct rcu_head *arg) {
+qpmulti_free_mem(dns_qpmulti_t *multi) {
+	REQUIRE(QPMULTI_VALID(multi));
+
+	/* reassure thread sanitizer */
+	LOCK(&multi->mutex);
+	dns_qp_t *qp = &multi->writer;
+	UNLOCK(&multi->mutex);
+
+	isc_mutex_destroy(&multi->mutex);
+	isc_mem_putanddetach(&qp->mctx, multi, sizeof(*multi));
+}
+
+#if QPMULTI_TRACE
+ISC_REFCOUNT_STATIC_TRACE_IMPL(dns_qpmulti, qpmulti_free_mem)
+#else
+ISC_REFCOUNT_STATIC_IMPL(dns_qpmulti, qpmulti_free_mem)
+#endif
+
+static void
+qpmulti_destroy_guts_cb(struct rcu_head *arg) {
 	qp_rcuctx_t *rcuctx = caa_container_of(arg, qp_rcuctx_t, rcu_head);
 	REQUIRE(QPRCU_VALID(rcuctx));
 	/* only nonzero for reclaim_chunks_cb() */
@@ -1518,10 +1592,9 @@ qpmulti_destroy_cb(struct rcu_head *arg) {
 
 	UNLOCK(&multi->mutex);
 
-	isc_mutex_destroy(&multi->mutex);
+	dns_qpmulti_detach(&multi);
 	isc_mem_putanddetach(&rcuctx->mctx, rcuctx,
 			     STRUCT_FLEX_SIZE(rcuctx, chunk, rcuctx->count));
-	isc_mem_putanddetach(&qp->mctx, multi, sizeof(*multi));
 }
 
 void
@@ -1547,7 +1620,7 @@ dns_qpmulti_destroy(dns_qpmulti_t **qpmp) {
 		.multi = multi,
 	};
 	isc_mem_attach(qp->mctx, &rcuctx->mctx);
-	call_rcu(&rcuctx->rcu_head, qpmulti_destroy_cb);
+	call_rcu(&rcuctx->rcu_head, qpmulti_destroy_guts_cb);
 }
 
 /***********************************************************************
@@ -1583,7 +1656,7 @@ dns_qp_insert(dns_qp_t *qp, void *pval, uint32_t ival) {
 		attach_leaf(qp, new_twigs);
 		qp->leaf_count++;
 		qp->root_ref = new_ref;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	/*
@@ -1607,7 +1680,7 @@ dns_qp_insert(dns_qp_t *qp, void *pval, uint32_t ival) {
 	old_keylen = leaf_qpkey(qp, n, old_key);
 	offset = qpkey_compare(new_key, new_keylen, old_key, old_keylen);
 	if (offset == QPKEY_EQUAL) {
-		return (ISC_R_EXISTS);
+		return ISC_R_EXISTS;
 	}
 	new_bit = qpkey_bit(new_key, new_keylen, offset);
 	old_bit = qpkey_bit(old_key, old_keylen, offset);
@@ -1648,7 +1721,7 @@ newbranch:
 	attach_leaf(qp, &new_leaf);
 	qp->leaf_count++;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 growbranch:
 	INSIST(!branch_has_twig(n, new_bit));
@@ -1680,7 +1753,7 @@ growbranch:
 	}
 	qp->leaf_count++;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -1690,7 +1763,7 @@ dns_qp_deletekey(dns_qp_t *qp, const dns_qpkey_t search_key,
 	REQUIRE(search_keylen < sizeof(dns_qpkey_t));
 
 	if (get_root(qp) == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	dns_qpshift_t bit = 0; /* suppress warning */
@@ -1700,7 +1773,7 @@ dns_qp_deletekey(dns_qp_t *qp, const dns_qpkey_t search_key,
 		prefetch_twigs(qp, n);
 		bit = branch_keybit(n, search_key, search_keylen);
 		if (!branch_has_twig(n, bit)) {
-			return (ISC_R_NOTFOUND);
+			return ISC_R_NOTFOUND;
 		}
 		make_twigs_mutable(qp, n);
 		parent = n;
@@ -1712,7 +1785,7 @@ dns_qp_deletekey(dns_qp_t *qp, const dns_qpkey_t search_key,
 	if (qpkey_compare(search_key, search_keylen, found_key, found_keylen) !=
 	    QPKEY_EQUAL)
 	{
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	SET_IF_NOT_NULL(pval_r, leaf_pval(n));
@@ -1726,7 +1799,7 @@ dns_qp_deletekey(dns_qp_t *qp, const dns_qpkey_t search_key,
 		INSIST(n == get_root(qp));
 		free_twigs(qp, qp->root_ref, 1);
 		qp->root_ref = INVALID_REF;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	/* step back to parent node */
@@ -1755,7 +1828,7 @@ dns_qp_deletekey(dns_qp_t *qp, const dns_qpkey_t search_key,
 		squash_twigs(qp, ref + size - 1, 1);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -1763,7 +1836,7 @@ dns_qp_deletename(dns_qp_t *qp, const dns_name_t *name, void **pval_r,
 		  uint32_t *ival_r) {
 	dns_qpkey_t key;
 	size_t keylen = dns_qpkey_fromname(key, name);
-	return (dns_qp_deletekey(qp, key, keylen, pval_r, ival_r));
+	return dns_qp_deletekey(qp, key, keylen, pval_r, ival_r);
 }
 
 /***********************************************************************
@@ -1799,7 +1872,7 @@ unsigned int
 dns_qpchain_length(dns_qpchain_t *chain) {
 	REQUIRE(QPCHAIN_VALID(chain));
 
-	return (chain->len);
+	return chain->len;
 }
 
 void
@@ -1846,7 +1919,7 @@ last_twig(dns_qpiter_t *qpi, bool forward) {
 			max = branch_twigs_size(parent) - 1;
 		}
 	}
-	return (pos == max);
+	return pos == max;
 }
 
 /*
@@ -1868,7 +1941,7 @@ iterate(bool forward, dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 
 	node = get_root(qp);
 	if (node == NULL) {
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
 	do {
@@ -1896,7 +1969,7 @@ iterate(bool forward, dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 				 * the iterator, then return ISC_R_NOMORE.
 				 */
 				dns_qpiter_init(qpi->qp, qpi);
-				return (ISC_R_NOMORE);
+				return ISC_R_NOMORE;
 			}
 
 			/*
@@ -1932,19 +2005,19 @@ iterate(bool forward, dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 	SET_IF_NOT_NULL(pval_r, leaf_pval(node));
 	SET_IF_NOT_NULL(ival_r, leaf_ival(node));
 	maybe_set_name(qpi->qp, node, name);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 dns_qpiter_next(dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 		uint32_t *ival_r) {
-	return (iterate(true, qpi, name, pval_r, ival_r));
+	return iterate(true, qpi, name, pval_r, ival_r);
 }
 
 isc_result_t
 dns_qpiter_prev(dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 		uint32_t *ival_r) {
-	return (iterate(false, qpi, name, pval_r, ival_r));
+	return iterate(false, qpi, name, pval_r, ival_r);
 }
 
 isc_result_t
@@ -1956,13 +2029,13 @@ dns_qpiter_current(dns_qpiter_t *qpi, dns_name_t *name, void **pval_r,
 
 	node = qpi->stack[qpi->sp];
 	if (node == NULL || is_branch(node)) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	SET_IF_NOT_NULL(pval_r, leaf_pval(node));
 	SET_IF_NOT_NULL(ival_r, leaf_ival(node));
 	maybe_set_name(qpi->qp, node, name);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /***********************************************************************
@@ -1984,14 +2057,14 @@ dns_qp_getkey(dns_qpreadable_t qpr, const dns_qpkey_t search_key,
 
 	n = get_root(qp);
 	if (n == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	while (is_branch(n)) {
 		prefetch_twigs(qp, n);
 		bit = branch_keybit(n, search_key, search_keylen);
 		if (!branch_has_twig(n, bit)) {
-			return (ISC_R_NOTFOUND);
+			return ISC_R_NOTFOUND;
 		}
 		n = branch_twig_ptr(qp, n, bit);
 	}
@@ -2000,12 +2073,12 @@ dns_qp_getkey(dns_qpreadable_t qpr, const dns_qpkey_t search_key,
 	if (qpkey_compare(search_key, search_keylen, found_key, found_keylen) !=
 	    QPKEY_EQUAL)
 	{
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	SET_IF_NOT_NULL(pval_r, leaf_pval(n));
 	SET_IF_NOT_NULL(ival_r, leaf_ival(n));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -2013,7 +2086,7 @@ dns_qp_getname(dns_qpreadable_t qpr, const dns_name_t *name, void **pval_r,
 	       uint32_t *ival_r) {
 	dns_qpkey_t key;
 	size_t keylen = dns_qpkey_fromname(key, name);
-	return (dns_qp_getkey(qpr, key, keylen, pval_r, ival_r));
+	return dns_qp_getkey(qpr, key, keylen, pval_r, ival_r);
 }
 
 static inline void
@@ -2053,7 +2126,7 @@ anyleaf(dns_qpreader_t *qp, dns_qpnode_t *n) {
 	while (is_branch(n)) {
 		n = branch_twigs(qp, n);
 	}
-	return (n);
+	return n;
 }
 
 static inline int
@@ -2061,9 +2134,9 @@ twig_offset(dns_qpnode_t *n, dns_qpshift_t sbit, dns_qpshift_t kbit,
 	    dns_qpshift_t fbit) {
 	dns_qpweight_t pos = branch_twig_pos(n, sbit);
 	if (branch_has_twig(n, sbit)) {
-		return (pos - (kbit < fbit));
+		return pos - (kbit < fbit);
 	}
-	return (pos - 1);
+	return pos - 1;
 }
 
 /*
@@ -2218,7 +2291,7 @@ dns_qp_lookup(dns_qpreadable_t qpr, const dns_name_t *name,
 
 	n = get_root(qp);
 	if (n == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 	iter->stack[0] = n;
 
@@ -2306,7 +2379,7 @@ dns_qp_lookup(dns_qpreadable_t qpr, const dns_name_t *name,
 		SET_IF_NOT_NULL(pval_r, leaf_pval(n));
 		SET_IF_NOT_NULL(ival_r, leaf_ival(n));
 		maybe_set_name(qp, n, foundname);
-		return (result);
+		return result;
 	}
 
 	/*
@@ -2320,7 +2393,7 @@ dns_qp_lookup(dns_qpreadable_t qpr, const dns_name_t *name,
 			SET_IF_NOT_NULL(pval_r, leaf_pval(n));
 			SET_IF_NOT_NULL(ival_r, leaf_ival(n));
 			maybe_set_name(qp, n, foundname);
-			return (DNS_R_PARTIALMATCH);
+			return DNS_R_PARTIALMATCH;
 		} else {
 			/*
 			 * oops, during the search we found and added
@@ -2332,7 +2405,7 @@ dns_qp_lookup(dns_qpreadable_t qpr, const dns_name_t *name,
 	}
 
 	/* nothing was found at all */
-	return (ISC_R_NOTFOUND);
+	return ISC_R_NOTFOUND;
 }
 
 /**********************************************************************/
