@@ -20,29 +20,29 @@
 
 #include <dns/ds.h>
 
-static inline isc_result_t
+static isc_result_t
 fromtext_dlv(ARGS_FROMTEXT) {
 	REQUIRE(type == dns_rdatatype_dlv);
 
-	return (generic_fromtext_ds(CALL_FROMTEXT));
+	return generic_fromtext_ds(CALL_FROMTEXT);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_dlv(ARGS_TOTEXT) {
 	REQUIRE(rdata != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_dlv);
 
-	return (generic_totext_ds(CALL_TOTEXT));
+	return generic_totext_ds(CALL_TOTEXT);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_dlv(ARGS_FROMWIRE) {
 	REQUIRE(type == dns_rdatatype_dlv);
 
-	return (generic_fromwire_ds(CALL_FROMWIRE));
+	return generic_fromwire_ds(CALL_FROMWIRE);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_dlv(ARGS_TOWIRE) {
 	isc_region_t sr;
 
@@ -52,10 +52,10 @@ towire_dlv(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline int
+static int
 compare_dlv(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -68,31 +68,29 @@ compare_dlv(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_dlv(ARGS_FROMSTRUCT) {
 	REQUIRE(type == dns_rdatatype_dlv);
 
-	return (generic_fromstruct_ds(CALL_FROMSTRUCT));
+	return generic_fromstruct_ds(CALL_FROMSTRUCT);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_dlv(ARGS_TOSTRUCT) {
 	dns_rdata_dlv_t *dlv = target;
 
 	REQUIRE(rdata->type == dns_rdatatype_dlv);
 	REQUIRE(dlv != NULL);
 
-	dlv->common.rdclass = rdata->rdclass;
-	dlv->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&dlv->common, link);
+	DNS_RDATACOMMON_INIT(dlv, rdata->type, rdata->rdclass);
 
-	return (generic_tostruct_ds(CALL_TOSTRUCT));
+	return generic_tostruct_ds(CALL_TOSTRUCT);
 }
 
-static inline void
+static void
 freestruct_dlv(ARGS_FREESTRUCT) {
 	dns_rdata_dlv_t *dlv = source;
 
@@ -109,7 +107,7 @@ freestruct_dlv(ARGS_FREESTRUCT) {
 	dlv->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_dlv(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_dlv);
 
@@ -118,10 +116,10 @@ additionaldata_dlv(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_dlv(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -129,10 +127,10 @@ digest_dlv(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_dlv(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_dlv);
 
@@ -141,10 +139,10 @@ checkowner_dlv(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_dlv(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_dlv);
 
@@ -152,12 +150,12 @@ checknames_dlv(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_dlv(ARGS_COMPARE) {
-	return (compare_dlv(rdata1, rdata2));
+	return compare_dlv(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_DLV_32769_C */
