@@ -36,7 +36,7 @@ fromtext_gpos(ARGS_FROMTEXT) {
 					      isc_tokentype_qstring, false));
 		RETTOK(txt_fromtext(&token.value.as_textregion, target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -58,7 +58,7 @@ totext_gpos(ARGS_TOTEXT) {
 		}
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -74,7 +74,7 @@ fromwire_gpos(ARGS_FROMWIRE) {
 	for (i = 0; i < 3; i++) {
 		RETERR(txt_fromwire(source, target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -84,7 +84,7 @@ towire_gpos(ARGS_TOWIRE) {
 
 	UNUSED(cctx);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
 static int
@@ -100,7 +100,7 @@ compare_gpos(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -120,7 +120,7 @@ fromstruct_gpos(ARGS_FROMSTRUCT) {
 	RETERR(uint8_tobuffer(gpos->lat_len, target));
 	RETERR(mem_tobuffer(target, gpos->latitude, gpos->lat_len));
 	RETERR(uint8_tobuffer(gpos->alt_len, target));
-	return (mem_tobuffer(target, gpos->altitude, gpos->alt_len));
+	return mem_tobuffer(target, gpos->altitude, gpos->alt_len);
 }
 
 static isc_result_t
@@ -132,9 +132,7 @@ tostruct_gpos(ARGS_TOSTRUCT) {
 	REQUIRE(gpos != NULL);
 	REQUIRE(rdata->length != 0);
 
-	gpos->common.rdclass = rdata->rdclass;
-	gpos->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&gpos->common, link);
+	DNS_RDATACOMMON_INIT(gpos, rdata->type, rdata->rdclass);
 
 	dns_rdata_toregion(rdata, &region);
 	gpos->long_len = uint8_fromregion(&region);
@@ -156,7 +154,7 @@ tostruct_gpos(ARGS_TOSTRUCT) {
 	}
 
 	gpos->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -191,7 +189,7 @@ additionaldata_gpos(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -202,7 +200,7 @@ digest_gpos(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -214,7 +212,7 @@ checkowner_gpos(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -225,12 +223,12 @@ checknames_gpos(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_gpos(ARGS_COMPARE) {
-	return (compare_gpos(rdata1, rdata2));
+	return compare_gpos(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_GPOS_27_C */
