@@ -502,9 +502,7 @@ tostruct_naptr(ARGS_TOSTRUCT) {
 	REQUIRE(naptr != NULL);
 	REQUIRE(rdata->length != 0);
 
-	naptr->common.rdclass = rdata->rdclass;
-	naptr->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&naptr->common, link);
+	DNS_RDATACOMMON_INIT(naptr, rdata->type, rdata->rdclass);
 
 	naptr->flags = NULL;
 	naptr->service = NULL;
