@@ -102,7 +102,7 @@ fromtext_nsec3(ARGS_FROMTEXT) {
 	RETERR(uint8_tobuffer(isc_buffer_usedlength(&b), target));
 	RETERR(mem_tobuffer(target, &buf, isc_buffer_usedlength(&b)));
 
-	return (typemap_fromtext(lexer, target, true));
+	return typemap_fromtext(lexer, target, true);
 }
 
 static isc_result_t
@@ -178,7 +178,7 @@ totext_nsec3(ARGS_TOTEXT) {
 		RETERR(str_totext(" )", target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -222,7 +222,7 @@ fromwire_nsec3(ARGS_FROMWIRE) {
 
 	RETERR(mem_tobuffer(target, rr.base, rr.length));
 	isc_buffer_forward(source, rr.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -235,7 +235,7 @@ towire_nsec3(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -251,7 +251,7 @@ compare_nsec3(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -280,7 +280,7 @@ fromstruct_nsec3(ARGS_FROMSTRUCT) {
 	region.base = nsec3->typebits;
 	region.length = nsec3->len;
 	RETERR(typemap_test(&region, true));
-	return (mem_tobuffer(target, nsec3->typebits, nsec3->len));
+	return mem_tobuffer(target, nsec3->typebits, nsec3->len);
 }
 
 static isc_result_t
@@ -292,9 +292,7 @@ tostruct_nsec3(ARGS_TOSTRUCT) {
 	REQUIRE(nsec3 != NULL);
 	REQUIRE(rdata->length != 0);
 
-	nsec3->common.rdclass = rdata->rdclass;
-	nsec3->common.rdtype = rdata->type;
-	ISC_LINK_INIT(&nsec3->common, link);
+	DNS_RDATACOMMON_INIT(nsec3, rdata->type, rdata->rdclass);
 
 	region.base = rdata->data;
 	region.length = rdata->length;
@@ -315,7 +313,7 @@ tostruct_nsec3(ARGS_TOSTRUCT) {
 	nsec3->len = region.length;
 	nsec3->typebits = mem_maybedup(mctx, region.base, region.length);
 	nsec3->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -350,7 +348,7 @@ additionaldata_nsec3(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -360,7 +358,7 @@ digest_nsec3(ARGS_DIGEST) {
 	REQUIRE(rdata->type == dns_rdatatype_nsec3);
 
 	dns_rdata_toregion(rdata, &r);
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -382,10 +380,10 @@ checkowner_nsec3(ARGS_CHECKOWNER) {
 	isc_region_consume(&label, 1);
 	isc_buffer_init(&buffer, owner, sizeof(owner));
 	if (isc_base32hexnp_decoderegion(&label, &buffer) == ISC_R_SUCCESS) {
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 static bool
@@ -396,12 +394,12 @@ checknames_nsec3(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_nsec3(ARGS_COMPARE) {
-	return (compare_nsec3(rdata1, rdata2));
+	return compare_nsec3(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_NSEC3_50_C */
