@@ -258,7 +258,7 @@ isc_httpdmgr_create(isc_nm_t *nm, isc_mem_t *mctx, isc_sockaddr_t *addr,
 	httpdmgr->magic = HTTPDMGR_MAGIC;
 	*httpdmgrp = httpdmgr;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	httpdmgr->magic = 0;
@@ -268,7 +268,7 @@ cleanup:
 	isc_mutex_destroy(&httpdmgr->lock);
 	isc_mem_put(mctx, httpdmgr, sizeof(isc_httpdmgr_t));
 
-	return (result);
+	return result;
 }
 
 static void
@@ -291,7 +291,7 @@ destroy_httpdmgr(isc_httpdmgr_t *httpdmgr) {
 	 * memory.
 	 */
 	isc_httpdurl_t *url, *next;
-	ISC_LIST_FOREACH_SAFE (httpdmgr->urls, url, link, next) {
+	ISC_LIST_FOREACH_SAFE(httpdmgr->urls, url, link, next) {
 		isc_mem_free(httpdmgr->mctx, url->url);
 		ISC_LIST_UNLINK(httpdmgr->urls, url, link);
 		isc_mem_put(httpdmgr->mctx, url, sizeof(isc_httpdurl_t));
@@ -316,9 +316,9 @@ static bool
 name_match(const struct phr_header *header, const char *match) {
 	size_t match_len = strlen(match);
 	if (match_len != header->name_len) {
-		return (false);
+		return false;
 	}
-	return (strncasecmp(header->name, match, match_len) == 0);
+	return strncasecmp(header->name, match, match_len) == 0;
 }
 
 static bool
@@ -327,7 +327,7 @@ value_match(const struct phr_header *header, const char *match) {
 	size_t limit;
 
 	if (match_len > header->value_len) {
-		return (false);
+		return false;
 	}
 
 	limit = header->value_len - match_len + 1;
@@ -351,7 +351,7 @@ value_match(const struct phr_header *header, const char *match) {
 			if (i == header->value_len || header->value[i] == ',' ||
 			    header->value[i] == ';')
 			{
-				return (true);
+				return true;
 			}
 		}
 
@@ -359,7 +359,7 @@ value_match(const struct phr_header *header, const char *match) {
 			i++;
 		}
 	}
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -382,16 +382,16 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 
 	if (pret == -1) {
 		/* Parse Error */
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	} else if (pret == -2) {
 		/* Need more data */
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
 	INSIST(pret > 0);
 
 	if (pret > HTTP_MAX_REQUEST_LEN) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	httpd->consume = pret;
@@ -405,7 +405,7 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 	} else if (strncmp(method, "POST ", method_len) == 0) {
 		httpd->method = METHOD_POST;
 	} else {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	/*
@@ -413,7 +413,7 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 	 */
 	result = isc_url_parse(path, path_len, 0, &httpd->up);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	httpd->path = path;
 
@@ -439,15 +439,15 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 
 			/* ensure we consumed all digits */
 			if ((header->value + header->value_len) != endptr) {
-				return (ISC_R_BADNUMBER);
+				return ISC_R_BADNUMBER;
 			}
 			/* ensure there was no minus sign */
 			if (val < 0) {
-				return (ISC_R_BADNUMBER);
+				return ISC_R_BADNUMBER;
 			}
 			/* ensure it did not overflow */
 			if (errno != 0) {
-				return (ISC_R_RANGE);
+				return ISC_R_RANGE;
 			}
 			content_len = val;
 		} else if (name_match(header, "Connection")) {
@@ -482,17 +482,17 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 	 * For a GET the length must be zero.
 	 */
 	if (httpd->method == METHOD_GET && content_len != 0) {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 
 	if (content_len >= HTTP_MAX_REQUEST_LEN) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	size_t consume = httpd->consume + content_len;
 	if (consume > httpd->recvlen) {
 		/* The request data isn't complete yet. */
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 
 	/* Consume the request's data, which we do not use. */
@@ -512,11 +512,11 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 		break;
 	case 1:
 		if (!host_header) {
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		break;
 	default:
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 
 	/*
@@ -527,7 +527,7 @@ process_request(isc_httpd_t *httpd, size_t last_len) {
 	 * to the buffer.
 	 */
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -606,7 +606,7 @@ isc__httpd_sendreq_new(isc_httpd_t *httpd) {
 
 	isc_httpd_attach(httpd, &req->httpd);
 
-	return (req);
+	return req;
 }
 
 static void
@@ -641,24 +641,24 @@ httpd_newconn(isc_nmhandle_t *handle, isc_result_t result, void *arg) {
 	REQUIRE(VALID_HTTPDMGR(httpdmgr));
 
 	if ((httpdmgr->flags & ISC_HTTPDMGR_SHUTTINGDOWN) != 0) {
-		return (ISC_R_CANCELED);
+		return ISC_R_CANCELED;
 	} else if (result == ISC_R_CANCELED) {
 		isc_httpdmgr_shutdown(&httpdmgr);
-		return (result);
+		return result;
 	} else if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	peeraddr = isc_nmhandle_peeraddr(handle);
 	if (httpdmgr->client_ok != NULL &&
 	    !(httpdmgr->client_ok)(&peeraddr, httpdmgr->cb_arg))
 	{
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	new_httpd(httpdmgr, handle);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -679,7 +679,7 @@ render_404(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo, void *arg,
 	*freecb = NULL;
 	*freecb_args = NULL;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -700,7 +700,7 @@ render_500(const isc_httpd_t *httpd, const isc_httpdurl_t *urlinfo, void *arg,
 	*freecb = NULL;
 	*freecb_args = NULL;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 #ifdef HAVE_ZLIB
@@ -728,7 +728,7 @@ httpd_compress(isc_httpd_sendreq_t *req) {
 	 */
 	inputlen = isc_buffer_usedlength(&req->bodybuffer);
 	if (inputlen == 0) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	isc_buffer_allocate(req->mctx, &req->compbuffer, inputlen);
@@ -749,10 +749,10 @@ httpd_compress(isc_httpd_sendreq_t *req) {
 	deflateEnd(&zstr);
 	if (ret == Z_STREAM_END) {
 		isc_buffer_add(req->compbuffer, zstr.total_out);
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	} else {
 		isc_buffer_free(&req->compbuffer);
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 }
 #endif /* ifdef HAVE_ZLIB */
@@ -781,7 +781,7 @@ prepare_response(void *arg) {
 	}
 
 	LOCK(&mgr->lock);
-	ISC_LIST_FOREACH (mgr->urls, url, link) {
+	ISC_LIST_FOREACH(mgr->urls, url, link) {
 		if (strncmp(path, url->url, path_len) == 0) {
 			break;
 		}
@@ -980,7 +980,7 @@ isc_httpdmgr_shutdown(isc_httpdmgr_t **httpdmgrp) {
 	LOCK(&httpdmgr->lock);
 
 	isc_httpd_t *httpd = NULL, *next = NULL;
-	ISC_LIST_FOREACH_SAFE (httpdmgr->running, httpd, link, next) {
+	ISC_LIST_FOREACH_SAFE(httpdmgr->running, httpd, link, next) {
 		if (httpd->handle != NULL) {
 			httpd_request(httpd->handle, ISC_R_SUCCESS, NULL,
 				      httpd);
@@ -1075,7 +1075,7 @@ isc_httpdmgr_addurl(isc_httpdmgr_t *httpdmgr, const char *url, bool isstatic,
 
 	if (url == NULL) {
 		httpdmgr->render_404 = func;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	item = isc_mem_get(httpdmgr->mctx, sizeof(isc_httpdurl_t));
@@ -1093,7 +1093,7 @@ isc_httpdmgr_addurl(isc_httpdmgr_t *httpdmgr, const char *url, bool isstatic,
 	ISC_LIST_APPEND(httpdmgr->urls, item, link);
 	UNLOCK(&httpdmgr->lock);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -1107,15 +1107,15 @@ isc_httpd_setfinishhook(void (*fn)(void)) {
 
 bool
 isc_httpdurl_isstatic(const isc_httpdurl_t *url) {
-	return (url->isstatic);
+	return url->isstatic;
 }
 
 const isc_time_t *
 isc_httpdurl_loadtime(const isc_httpdurl_t *url) {
-	return (&url->loadtime);
+	return &url->loadtime;
 }
 
 const isc_time_t *
 isc_httpd_if_modified_since(const isc_httpd_t *httpd) {
-	return ((const isc_time_t *)&httpd->if_modified_since);
+	return (const isc_time_t *)&httpd->if_modified_since;
 }
