@@ -226,6 +226,8 @@ typedef enum isc_result {
 	DNS_R_HAVEPARMKEYS,
 	DNS_R_NOALPN,
 	DNS_R_NODOHPATH,
+	DNS_R_NOSKRFILE,
+	DNS_R_NOSKRBUNDLE,
 
 	DST_R_UNSUPPORTEDALG,
 	DST_R_CRYPTOFAILURE,
