@@ -38,7 +38,7 @@ isc_iterated_hash(unsigned char *out, const unsigned int hashalg,
 	SHA_CTX ctx;
 
 	if (hashalg != 1) {
-		return (0);
+		return 0;
 	}
 
 	buf = in;
@@ -47,29 +47,29 @@ isc_iterated_hash(unsigned char *out, const unsigned int hashalg,
 	do {
 		if (SHA1_Init(&ctx) != 1) {
 			ERR_clear_error();
-			return (0);
+			return 0;
 		}
 
 		if (SHA1_Update(&ctx, buf, len) != 1) {
 			ERR_clear_error();
-			return (0);
+			return 0;
 		}
 
 		if (SHA1_Update(&ctx, salt, saltlength) != 1) {
 			ERR_clear_error();
-			return (0);
+			return 0;
 		}
 
 		if (SHA1_Final(out, &ctx) != 1) {
 			ERR_clear_error();
-			return (0);
+			return 0;
 		}
 
 		buf = out;
 		len = SHA_DIGEST_LENGTH;
 	} while (n++ < iterations);
 
-	return (SHA_DIGEST_LENGTH);
+	return SHA_DIGEST_LENGTH;
 }
 
 void
@@ -106,7 +106,7 @@ isc_iterated_hash(unsigned char *out, const unsigned int hashalg,
 	const unsigned char *buf;
 
 	if (hashalg != 1) {
-		return (0);
+		return 0;
 	}
 
 	buf = in;
@@ -132,11 +132,11 @@ isc_iterated_hash(unsigned char *out, const unsigned int hashalg,
 		len = outlength;
 	} while (n++ < iterations);
 
-	return (outlength);
+	return outlength;
 
 fail:
 	ERR_clear_error();
-	return (0);
+	return 0;
 }
 
 void
