@@ -13,7 +13,6 @@
 
 /*! \file */
 
-#include <errno.h>
 #include <inttypes.h>
 #include <limits.h>
 #include <stdbool.h>
@@ -85,11 +84,12 @@ volatile void *isc__mem_malloc = mallocx;
 #if ISC_MEM_TRACKLINES
 typedef struct debuglink debuglink_t;
 struct debuglink {
+	size_t dlsize;
 	ISC_LINK(debuglink_t) link;
 	const void *ptr;
 	size_t size;
-	const char *file;
 	unsigned int line;
+	const char file[];
 };
 
 typedef ISC_LIST(debuglink_t) debuglist_t;
@@ -191,9 +191,6 @@ static void
 print_active(isc_mem_t *ctx, FILE *out);
 #endif /* ISC_MEM_TRACKLINES */
 
-static void
-isc__mem_rcu_barrier(isc_mem_t *ctx);
-
 #if ISC_MEM_TRACKLINES
 /*!
  * mctx must not be locked.
@@ -204,6 +201,15 @@ add_trace_entry(isc_mem_t *mctx, const void *ptr, size_t size FLARG) {
 	uint32_t hash;
 	uint32_t idx;
 
+	/*
+	 * "file" needs to be copied because it can be part of a dynamically
+	 * loaded plugin which would be unloaded at the time the trace is
+	 * dumped. Storing "file" pointer then leads to a dangling pointer
+	 * dereference and a crash.
+	 */
+	size_t filelen = strlen(file) + 1;
+	size_t dlsize = STRUCT_FLEX_SIZE(dl, file, filelen);
+
 	MCTXLOCK(mctx);
 
 	if ((mctx->debugging & ISC_MEM_DEBUGTRACE) != 0) {
@@ -226,14 +232,15 @@ add_trace_entry(isc_mem_t *mctx, const void *ptr, size_t size FLARG) {
 #endif
 	idx = hash % DEBUG_TABLE_COUNT;
 
-	dl = mallocx(sizeof(debuglink_t), mctx->jemalloc_flags);
+	dl = mallocx(dlsize, mctx->jemalloc_flags);
 	INSIST(dl != NULL);
 
 	ISC_LINK_INIT(dl, link);
 	dl->ptr = ptr;
 	dl->size = size;
-	dl->file = file;
 	dl->line = line;
+	dl->dlsize = dlsize;
+	strlcpy((char *)dl->file, file, filelen);
 
 	ISC_LIST_PREPEND(mctx->debuglist[idx], dl, link);
 	mctx->debuglistcnt++;
@@ -274,7 +281,7 @@ delete_trace_entry(isc_mem_t *mctx, const void *ptr, size_t size,
 	while (dl != NULL) {
 		if (dl->ptr == ptr) {
 			ISC_LIST_UNLINK(mctx->debuglist[idx], dl, link);
-			sdallocx(dl, sizeof(*dl), mctx->jemalloc_flags);
+			sdallocx(dl, dl->dlsize, mctx->jemalloc_flags);
 			goto unlock;
 		}
 		dl = ISC_LIST_NEXT(dl, link);
@@ -313,7 +320,7 @@ mem_get(isc_mem_t *ctx, size_t size, int flags) {
 		memset(ret, 0xbe, size); /* Mnemonic for "beef". */
 	}
 
-	return (ret);
+	return ret;
 }
 
 /*!
@@ -351,7 +358,7 @@ mem_realloc(isc_mem_t *ctx, void *old_ptr, size_t old_size, size_t new_size,
 		}
 	}
 
-	return (new_ptr);
+	return new_ptr;
 }
 
 /*!
@@ -386,15 +393,15 @@ mem_jemalloc_arena_create(unsigned int *pnew_arenano) {
 
 	res = mallctl("arenas.create", &arenano, &len, NULL, 0);
 	if (res != 0) {
-		return (false);
+		return false;
 	}
 
 	*pnew_arenano = arenano;
 
-	return (true);
+	return true;
 #else
 	*pnew_arenano = ISC_MEM_ILLEGAL_ARENA;
-	return (true);
+	return true;
 #endif /* JEMALLOC_API_SUPPORTED */
 }
 
@@ -407,13 +414,13 @@ mem_jemalloc_arena_destroy(unsigned int arenano) {
 	(void)snprintf(buf, sizeof(buf), "arena.%u.destroy", arenano);
 	res = mallctl(buf, NULL, NULL, NULL, 0);
 	if (res != 0) {
-		return (false);
+		return false;
 	}
 
-	return (true);
+	return true;
 #else
 	UNUSED(arenano);
-	return (true);
+	return true;
 #endif /* JEMALLOC_API_SUPPORTED */
 }
 
@@ -439,6 +446,8 @@ static void
 mem_shutdown(void) {
 	bool empty;
 
+	rcu_barrier();
+
 	isc__mem_checkdestroyed();
 
 	LOCK(&contextslock);
@@ -587,7 +596,6 @@ isc__mem_detach(isc_mem_t **ctxp FLARG) {
 				ctx, file, line);
 		}
 #endif
-		isc__mem_rcu_barrier(ctx);
 		destroy(ctx);
 	}
 }
@@ -616,39 +624,6 @@ isc__mem_putanddetach(isc_mem_t **ctxp, void *ptr, size_t size,
 	isc__mem_detach(&ctx FLARG_PASS);
 }
 
-static void
-isc__mem_rcu_barrier(isc_mem_t *ctx) {
-	/*
-	 * wait for asynchronous memory reclamation to complete
-	 * before checking for memory leaks.
-	 *
-	 * Because rcu_barrier() needs to be called as many times
-	 * as the number of nested call_rcu() calls (call_rcu()
-	 * calls made from call_rcu thread), and currently there's
-	 * no mechanism to detect whether there are more call_rcu
-	 * callbacks scheduled, we simply call the rcu_barrier()
-	 * until there's no progression in the memory freed.
-	 *
-	 * The overhead is negligible and it prevents rare assertion failures
-	 * caused by the check for memory leaks below.
-	 */
-	size_t inuse;
-	uint_fast32_t references;
-	for (inuse = atomic_load(&ctx->inuse),
-	    references = isc_refcount_current(&ctx->references);
-	     inuse > 0 || references > 1; inuse = atomic_load(&ctx->inuse),
-	    references = isc_refcount_current(&ctx->references))
-	{
-		rcu_barrier();
-
-		if (inuse == atomic_load(&ctx->inuse) &&
-		    references == isc_refcount_current(&ctx->references))
-		{
-			break;
-		}
-	}
-}
-
 void
 isc__mem_destroy(isc_mem_t **ctxp FLARG) {
 	isc_mem_t *ctx = NULL;
@@ -663,7 +638,7 @@ isc__mem_destroy(isc_mem_t **ctxp FLARG) {
 	ctx = *ctxp;
 	*ctxp = NULL;
 
-	isc__mem_rcu_barrier(ctx);
+	rcu_barrier();
 
 #if ISC_MEM_TRACKLINES
 	if ((ctx->debugging & ISC_MEM_DEBUGTRACE) != 0) {
@@ -694,7 +669,7 @@ isc__mem_get(isc_mem_t *ctx, size_t size, int flags FLARG) {
 	mem_getstats(ctx, size);
 	ADD_TRACE(ctx, ptr, size, file, line);
 
-	return (ptr);
+	return ptr;
 }
 
 void
@@ -800,7 +775,7 @@ isc__mem_allocate(isc_mem_t *ctx, size_t size, int flags FLARG) {
 	mem_getstats(ctx, size);
 	ADD_TRACE(ctx, ptr, size, file, line);
 
-	return (ptr);
+	return ptr;
 }
 
 void *
@@ -829,7 +804,7 @@ isc__mem_reget(isc_mem_t *ctx, void *old_ptr, size_t old_size, size_t new_size,
 		 */
 	}
 
-	return (new_ptr);
+	return new_ptr;
 }
 
 void *
@@ -864,7 +839,7 @@ isc__mem_reallocate(isc_mem_t *ctx, void *old_ptr, size_t new_size,
 		 */
 	}
 
-	return (new_ptr);
+	return new_ptr;
 }
 
 void
@@ -900,7 +875,7 @@ isc__mem_strdup(isc_mem_t *mctx, const char *s FLARG) {
 
 	strlcpy(ns, s, len);
 
-	return (ns);
+	return ns;
 }
 
 char *
@@ -921,7 +896,7 @@ isc__mem_strndup(isc_mem_t *mctx, const char *s, size_t size FLARG) {
 
 	strlcpy(ns, s, len);
 
-	return (ns);
+	return ns;
 }
 
 void
@@ -939,7 +914,7 @@ size_t
 isc_mem_inuse(isc_mem_t *ctx) {
 	REQUIRE(VALID_CONTEXT(ctx));
 
-	return (atomic_load_relaxed(&ctx->inuse));
+	return atomic_load_relaxed(&ctx->inuse);
 }
 
 void
@@ -968,12 +943,12 @@ isc_mem_isovermem(isc_mem_t *ctx) {
 		/* We are not overmem, check whether we should be? */
 		size_t hiwater = atomic_load_relaxed(&ctx->hi_water);
 		if (hiwater == 0) {
-			return (false);
+			return false;
 		}
 
 		size_t inuse = atomic_load_relaxed(&ctx->inuse);
 		if (inuse <= hiwater) {
-			return (false);
+			return false;
 		}
 
 		if ((isc_mem_debugging & ISC_MEM_DEBUGUSAGE) != 0) {
@@ -983,17 +958,17 @@ isc_mem_isovermem(isc_mem_t *ctx) {
 		}
 
 		atomic_store_relaxed(&ctx->is_overmem, true);
-		return (true);
+		return true;
 	} else {
 		/* We are overmem, check whether we should not be? */
 		size_t lowater = atomic_load_relaxed(&ctx->lo_water);
 		if (lowater == 0) {
-			return (false);
+			return false;
 		}
 
 		size_t inuse = atomic_load_relaxed(&ctx->inuse);
 		if (inuse >= lowater) {
-			return (true);
+			return true;
 		}
 
 		if ((isc_mem_debugging & ISC_MEM_DEBUGUSAGE) != 0) {
@@ -1002,7 +977,7 @@ isc_mem_isovermem(isc_mem_t *ctx) {
 				inuse, lowater);
 		}
 		atomic_store_relaxed(&ctx->is_overmem, false);
-		return (false);
+		return false;
 	}
 }
 
@@ -1020,10 +995,10 @@ isc_mem_getname(isc_mem_t *ctx) {
 	REQUIRE(VALID_CONTEXT(ctx));
 
 	if (ctx->name[0] == 0) {
-		return ("");
+		return "";
 	}
 
-	return (ctx->name);
+	return ctx->name;
 }
 
 /*
@@ -1176,7 +1151,7 @@ isc__mempool_get(isc_mempool_t *restrict mpctx FLARG) {
 
 	ADD_TRACE(mpctx->mctx, item, mpctx->size, file, line);
 
-	return (item);
+	return item;
 }
 
 /* coverity[+free : arg-1] */
@@ -1233,21 +1208,21 @@ unsigned int
 isc_mempool_getfreemax(isc_mempool_t *restrict mpctx) {
 	REQUIRE(VALID_MEMPOOL(mpctx));
 
-	return (mpctx->freemax);
+	return mpctx->freemax;
 }
 
 unsigned int
 isc_mempool_getfreecount(isc_mempool_t *restrict mpctx) {
 	REQUIRE(VALID_MEMPOOL(mpctx));
 
-	return (mpctx->freecount);
+	return mpctx->freecount;
 }
 
 unsigned int
 isc_mempool_getallocated(isc_mempool_t *restrict mpctx) {
 	REQUIRE(VALID_MEMPOOL(mpctx));
 
-	return (mpctx->allocated);
+	return mpctx->allocated;
 }
 
 void
@@ -1263,7 +1238,7 @@ unsigned int
 isc_mempool_getfillcount(isc_mempool_t *restrict mpctx) {
 	REQUIRE(VALID_MEMPOOL(mpctx));
 
-	return (mpctx->fillcount);
+	return mpctx->fillcount;
 }
 
 /*
@@ -1315,7 +1290,7 @@ isc__mem_checkdestroyed(void) {
 
 unsigned int
 isc_mem_references(isc_mem_t *ctx) {
-	return (isc_refcount_current(&ctx->references));
+	return isc_refcount_current(&ctx->references);
 }
 
 #ifdef HAVE_LIBXML2
@@ -1383,7 +1358,7 @@ xml_renderctx(isc_mem_t *ctx, size_t *inuse, xmlTextWriterPtr writer) {
 error:
 	MCTXUNLOCK(ctx);
 
-	return (xmlrc);
+	return xmlrc;
 }
 
 int
@@ -1423,7 +1398,7 @@ isc_mem_renderxml(void *writer0) {
 
 	TRY0(xmlTextWriterEndElement(writer)); /* summary */
 error:
-	return (xmlrc);
+	return xmlrc;
 }
 
 #endif /* HAVE_LIBXML2 */
@@ -1483,7 +1458,7 @@ json_renderctx(isc_mem_t *ctx, size_t *inuse, json_object *array) {
 
 	MCTXUNLOCK(ctx);
 	json_object_array_add(array, ctxobj);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -1518,13 +1493,13 @@ isc_mem_renderjson(void *memobj0) {
 	json_object_object_add(memobj, "Malloced", obj);
 
 	json_object_object_add(memobj, "contexts", ctxarray);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 error:
 	if (ctxarray != NULL) {
 		json_object_put(ctxarray);
 	}
-	return (result);
+	return result;
 }
 #endif /* HAVE_JSON_C */
 
@@ -1573,7 +1548,7 @@ jemalloc_set_ssize_value(const char *valname, ssize_t newval) {
 	int ret;
 
 	ret = mallctl(valname, NULL, NULL, &newval, sizeof(newval));
-	return (ret == 0);
+	return ret == 0;
 }
 #endif /* JEMALLOC_API_SUPPORTED */
 
@@ -1586,7 +1561,7 @@ mem_set_arena_ssize_value(isc_mem_t *mctx, const char *arena_valname,
 	char buf[256] = { 0 };
 
 	if (mctx->jemalloc_arena == ISC_MEM_ILLEGAL_ARENA) {
-		return (ISC_R_UNEXPECTED);
+		return ISC_R_UNEXPECTED;
 	}
 
 	(void)snprintf(buf, sizeof(buf), "arena.%u.%s", mctx->jemalloc_arena,
@@ -1595,25 +1570,25 @@ mem_set_arena_ssize_value(isc_mem_t *mctx, const char *arena_valname,
 	ret = jemalloc_set_ssize_value(buf, newval);
 
 	if (!ret) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 #else
 	UNUSED(arena_valname);
 	UNUSED(newval);
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 #endif
 }
 
 isc_result_t
 isc_mem_arena_set_muzzy_decay_ms(isc_mem_t *mctx, const ssize_t decay_ms) {
-	return (mem_set_arena_ssize_value(mctx, "muzzy_decay_ms", decay_ms));
+	return mem_set_arena_ssize_value(mctx, "muzzy_decay_ms", decay_ms);
 }
 
 isc_result_t
 isc_mem_arena_set_dirty_decay_ms(isc_mem_t *mctx, const ssize_t decay_ms) {
-	return (mem_set_arena_ssize_value(mctx, "dirty_decay_ms", decay_ms));
+	return mem_set_arena_ssize_value(mctx, "dirty_decay_ms", decay_ms);
 }
 
 void
