@@ -80,14 +80,10 @@
 
 #ifdef __OpenBSD__
 #define USE_SYSCTL_PORTRANGE
-#define SYSCTL_V4PORTRANGE_LOW                                         \
-	{                                                              \
-		CTL_NET, PF_INET, IPPROTO_IP, IPCTL_IPPORT_HIFIRSTAUTO \
-	}
-#define SYSCTL_V4PORTRANGE_HIGH                                       \
-	{                                                             \
-		CTL_NET, PF_INET, IPPROTO_IP, IPCTL_IPPORT_HILASTAUTO \
-	}
+#define SYSCTL_V4PORTRANGE_LOW \
+	{ CTL_NET, PF_INET, IPPROTO_IP, IPCTL_IPPORT_HIFIRSTAUTO }
+#define SYSCTL_V4PORTRANGE_HIGH \
+	{ CTL_NET, PF_INET, IPPROTO_IP, IPCTL_IPPORT_HILASTAUTO }
 /* Same for IPv6 */
 #define SYSCTL_V6PORTRANGE_LOW	SYSCTL_V4PORTRANGE_LOW
 #define SYSCTL_V6PORTRANGE_HIGH SYSCTL_V4PORTRANGE_HIGH
@@ -135,10 +131,10 @@ try_proto(int domain) {
 #ifdef EINVAL
 		case EINVAL:
 #endif /* ifdef EINVAL */
-			return (ISC_R_NOTFOUND);
+			return ISC_R_NOTFOUND;
 		default:
 			UNEXPECTED_SYSERROR(errno, "socket()");
-			return (ISC_R_UNEXPECTED);
+			return ISC_R_UNEXPECTED;
 		}
 	}
 
@@ -180,7 +176,7 @@ try_proto(int domain) {
 
 	(void)close(s);
 
-	return (result);
+	return result;
 }
 
 static void
@@ -197,13 +193,13 @@ initialize(void) {
 isc_result_t
 isc_net_probeipv4(void) {
 	initialize();
-	return (ipv4_result);
+	return ipv4_result;
 }
 
 isc_result_t
 isc_net_probeipv6(void) {
 	initialize();
-	return (ipv6_result);
+	return ipv6_result;
 }
 
 static void
@@ -314,7 +310,7 @@ initialize_ipv6pktinfo(void) {
 isc_result_t
 isc_net_probe_ipv6only(void) {
 	initialize_ipv6only();
-	return (ipv6only_result);
+	return ipv6only_result;
 }
 
 isc_result_t
@@ -331,7 +327,7 @@ isc_net_probe_ipv6pktinfo(void) {
 #ifdef __notyet__
 	initialize_ipv6pktinfo();
 #endif /* ifdef __notyet__ */
-	return (ipv6pktinfo_result);
+	return ipv6pktinfo_result;
 }
 
 #if defined(USE_SYSCTL_PORTRANGE)
@@ -352,21 +348,21 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high) {
 	portlen = sizeof(port_low);
 	if (sysctlbyname(sysctlname_lowport, &port_low, &portlen, NULL, 0) < 0)
 	{
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 	portlen = sizeof(port_high);
 	if (sysctlbyname(sysctlname_hiport, &port_high, &portlen, NULL, 0) < 0)
 	{
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	*low = (in_port_t)port_low;
 	*high = (in_port_t)port_high;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 #else  /* !HAVE_SYSCTLBYNAME */
 static isc_result_t
@@ -391,22 +387,22 @@ getudpportrange_sysctl(int af, in_port_t *low, in_port_t *high) {
 
 	portlen = sizeof(port_low);
 	if (sysctl(mib_lo, miblen, &port_low, &portlen, NULL, 0) < 0) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	portlen = sizeof(port_high);
 	if (sysctl(mib_hi, miblen, &port_high, &portlen, NULL, 0) < 0) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	if ((port_low & ~0xffff) != 0 || (port_high & ~0xffff) != 0) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	*low = (in_port_t)port_low;
 	*high = (in_port_t)port_high;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 #endif /* HAVE_SYSCTLBYNAME */
 #endif /* USE_SYSCTL_PORTRANGE */
@@ -451,7 +447,7 @@ isc_net_getudpportrange(int af, in_port_t *low, in_port_t *high) {
 		*high = ISC_NET_PORTRANGEHIGH;
 	}
 
-	return (ISC_R_SUCCESS); /* we currently never fail in this function */
+	return ISC_R_SUCCESS; /* we currently never fail in this function */
 }
 
 void
