@@ -194,7 +194,7 @@ isc_ratelimiter_enqueue(isc_ratelimiter_t *restrict rl,
 		UNREACHABLE();
 	}
 	UNLOCK(&rl->lock);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -212,7 +212,7 @@ isc_ratelimiter_dequeue(isc_ratelimiter_t *restrict rl, isc_rlevent_t **rlep) {
 		result = ISC_R_NOTFOUND;
 	}
 	UNLOCK(&rl->lock);
-	return (result);
+	return result;
 }
 
 static void
@@ -313,8 +313,6 @@ isc_ratelimiter_shutdown(isc_ratelimiter_t *restrict rl) {
 
 static void
 ratelimiter_destroy(isc_ratelimiter_t *restrict rl) {
-	isc_refcount_destroy(&rl->references);
-
 	LOCK(&rl->lock);
 	REQUIRE(rl->state == isc_ratelimiter_shuttingdown);
 	UNLOCK(&rl->lock);
