@@ -44,7 +44,7 @@
 #ifndef BIT_AT
 #define BIT_AT(a, i)                                    \
 	(!!((unsigned int)(a)[(unsigned int)(i) >> 3] & \
-	    (1 << ((unsigned int)(i)&7))))
+	    (1 << ((unsigned int)(i) & 7))))
 #endif
 
 #if HTTP_PARSER_STRICT
@@ -201,7 +201,8 @@ typedef enum {
 #define IS_URL_CHAR(c)	(BIT_AT(normal_url_char, (unsigned char)c))
 #define IS_HOST_CHAR(c) (isalnum((unsigned char)c) || (c) == '.' || (c) == '-')
 #else
-#define IS_URL_CHAR(c) (BIT_AT(normal_url_char, (unsigned char)c) || ((c)&0x80))
+#define IS_URL_CHAR(c) \
+	(BIT_AT(normal_url_char, (unsigned char)c) || ((c) & 0x80))
 #define IS_HOST_CHAR(c) \
 	(isalnum((unsigned char)c) || (c) == '.' || (c) == '-' || (c) == '_')
 #endif
@@ -221,12 +222,12 @@ typedef enum {
 static state_t
 parse_url_char(state_t s, const char ch) {
 	if (ch == ' ' || ch == '\r' || ch == '\n') {
-		return (s_dead);
+		return s_dead;
 	}
 
 #if HTTP_PARSER_STRICT
 	if (ch == '\t' || ch == '\f') {
-		return (s_dead);
+		return s_dead;
 	}
 #endif
 
@@ -238,77 +239,77 @@ parse_url_char(state_t s, const char ch) {
 		 */
 
 		if (ch == '/' || ch == '*') {
-			return (s_req_path);
+			return s_req_path;
 		}
 
 		if (isalpha((unsigned char)ch)) {
-			return (s_req_schema);
+			return s_req_schema;
 		}
 
 		break;
 
 	case s_req_schema:
 		if (isalpha((unsigned char)ch)) {
-			return (s);
+			return s;
 		}
 
 		if (ch == ':') {
-			return (s_req_schema_slash);
+			return s_req_schema_slash;
 		}
 
 		break;
 
 	case s_req_schema_slash:
 		if (ch == '/') {
-			return (s_req_schema_slash_slash);
+			return s_req_schema_slash_slash;
 		}
 
 		break;
 
 	case s_req_schema_slash_slash:
 		if (ch == '/') {
-			return (s_req_server_start);
+			return s_req_server_start;
 		}
 
 		break;
 
 	case s_req_server_with_at:
 		if (ch == '@') {
-			return (s_dead);
+			return s_dead;
 		}
 
 		FALLTHROUGH;
 	case s_req_server_start:
 	case s_req_server:
 		if (ch == '/') {
-			return (s_req_path);
+			return s_req_path;
 		}
 
 		if (ch == '?') {
-			return (s_req_query_string_start);
+			return s_req_query_string_start;
 		}
 
 		if (ch == '@') {
-			return (s_req_server_with_at);
+			return s_req_server_with_at;
 		}
 
 		if (IS_USERINFO_CHAR(ch) || ch == '[' || ch == ']') {
-			return (s_req_server);
+			return s_req_server;
 		}
 
 		break;
 
 	case s_req_path:
 		if (IS_URL_CHAR(ch)) {
-			return (s);
+			return s;
 		}
 
 		switch (ch) {
 		case '?':
-			return (s_req_query_string_start);
+			return s_req_query_string_start;
 
 		case '#':
-			return (s_req_fragment_start);
+			return s_req_fragment_start;
 		}
 
 		break;
@@ -316,44 +317,44 @@ parse_url_char(state_t s, const char ch) {
 	case s_req_query_string_start:
 	case s_req_query_string:
 		if (IS_URL_CHAR(ch)) {
-			return (s_req_query_string);
+			return s_req_query_string;
 		}
 
 		switch (ch) {
 		case '?':
 			/* allow extra '?' in query string */
-			return (s_req_query_string);
+			return s_req_query_string;
 
 		case '#':
-			return (s_req_fragment_start);
+			return s_req_fragment_start;
 		}
 
 		break;
 
 	case s_req_fragment_start:
 		if (IS_URL_CHAR(ch)) {
-			return (s_req_fragment);
+			return s_req_fragment;
 		}
 
 		switch (ch) {
 		case '?':
-			return (s_req_fragment);
+			return s_req_fragment;
 
 		case '#':
-			return (s);
+			return s;
 		}
 
 		break;
 
 	case s_req_fragment:
 		if (IS_URL_CHAR(ch)) {
-			return (s);
+			return s;
 		}
 
 		switch (ch) {
 		case '?':
 		case '#':
-			return (s);
+			return s;
 		}
 
 		break;
@@ -366,7 +367,7 @@ parse_url_char(state_t s, const char ch) {
 	 * We should never fall out of the switch above unless there's an
 	 * error.
 	 */
-	return (s_dead);
+	return s_dead;
 }
 
 static host_state_t
@@ -375,57 +376,57 @@ http_parse_host_char(host_state_t s, const char ch) {
 	case s_http_userinfo:
 	case s_http_userinfo_start:
 		if (ch == '@') {
-			return (s_http_host_start);
+			return s_http_host_start;
 		}
 
 		if (IS_USERINFO_CHAR(ch)) {
-			return (s_http_userinfo);
+			return s_http_userinfo;
 		}
 		break;
 
 	case s_http_host_start:
 		if (ch == '[') {
-			return (s_http_host_v6_start);
+			return s_http_host_v6_start;
 		}
 
 		if (IS_HOST_CHAR(ch)) {
-			return (s_http_host);
+			return s_http_host;
 		}
 
 		break;
 
 	case s_http_host:
 		if (IS_HOST_CHAR(ch)) {
-			return (s_http_host);
+			return s_http_host;
 		}
 
 		FALLTHROUGH;
 	case s_http_host_v6_end:
 		if (ch == ':') {
-			return (s_http_host_port_start);
+			return s_http_host_port_start;
 		}
 
 		break;
 
 	case s_http_host_v6:
 		if (ch == ']') {
-			return (s_http_host_v6_end);
+			return s_http_host_v6_end;
 		}
 
 		FALLTHROUGH;
 	case s_http_host_v6_start:
 		if (isxdigit((unsigned char)ch) || ch == ':' || ch == '.') {
-			return (s_http_host_v6);
+			return s_http_host_v6;
 		}
 
 		if (s == s_http_host_v6 && ch == '%') {
-			return (s_http_host_v6_zone_start);
+			return s_http_host_v6_zone_start;
 		}
 		break;
 
 	case s_http_host_v6_zone:
 		if (ch == ']') {
-			return (s_http_host_v6_end);
+			return s_http_host_v6_end;
 		}
 
 		FALLTHROUGH;
@@ -434,14 +435,14 @@ http_parse_host_char(host_state_t s, const char ch) {
 		if (isalnum((unsigned char)ch) || ch == '%' || ch == '.' ||
 		    ch == '-' || ch == '_' || ch == '~')
 		{
-			return (s_http_host_v6_zone);
+			return s_http_host_v6_zone;
 		}
 		break;
 
 	case s_http_host_port:
 	case s_http_host_port_start:
 		if (isdigit((unsigned char)ch)) {
-			return (s_http_host_port);
+			return s_http_host_port;
 		}
 
 		break;
@@ -450,7 +451,7 @@ http_parse_host_char(host_state_t s, const char ch) {
 		break;
 	}
 
-	return (s_http_host_dead);
+	return s_http_host_dead;
 }
 
 static isc_result_t
@@ -470,7 +471,7 @@ http_parse_host(const char *buf, isc_url_parser_t *up, int found_at) {
 		host_state_t new_s = http_parse_host_char(s, *p);
 
 		if (new_s == s_http_host_dead) {
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 
 		switch (new_s) {
@@ -532,12 +533,12 @@ http_parse_host(const char *buf, isc_url_parser_t *up, int found_at) {
 	case s_http_host_port_start:
 	case s_http_userinfo:
 	case s_http_userinfo_start:
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	default:
 		break;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -549,7 +550,7 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 	const char *p = NULL;
 
 	if (buflen == 0) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	up->port = up->field_set = 0;
@@ -562,7 +563,7 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 		/* Figure out the next field that we're operating on */
 		switch (s) {
 		case s_dead:
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 
 		/* Skip delimiters */
 		case s_req_schema_slash:
@@ -617,7 +618,7 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 	if ((up->field_set & (1 << ISC_UF_SCHEMA)) &&
 	    (up->field_set & (1 << ISC_UF_HOST)) == 0)
 	{
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	if (up->field_set & (1 << ISC_UF_HOST)) {
@@ -625,7 +626,7 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 
 		result = http_parse_host(buf, up, found_at);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 	}
 
@@ -633,7 +634,7 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 	if (is_connect &&
 	    up->field_set != ((1 << ISC_UF_HOST) | (1 << ISC_UF_PORT)))
 	{
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	if (up->field_set & (1 << ISC_UF_PORT)) {
@@ -660,12 +661,12 @@ isc_url_parse(const char *buf, size_t buflen, bool is_connect,
 
 			/* Ports have a max value of 2^16 */
 			if (v > 0xffff) {
-				return (ISC_R_RANGE);
+				return ISC_R_RANGE;
 			}
 		}
 
 		up->port = (uint16_t)v;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
