@@ -46,14 +46,14 @@ static int
 setup_test(void **state) {
 	setup_loopmgr(state);
 
-	return (0);
+	return 0;
 }
 
 static int
 teardown_test(void **state) {
 	teardown_loopmgr(state);
 
-	return (0);
+	return 0;
 }
 
 dns_keytable_t *keytable = NULL;
@@ -99,7 +99,7 @@ str2name(const char *namestr) {
 		dns_name_fromtext(name, &namebuf, dns_rootname, 0, NULL),
 		ISC_R_SUCCESS);
 
-	return (name);
+	return name;
 }
 
 static void
@@ -170,12 +170,11 @@ create_tables(void) {
 	dns_name_t *keyname = dns_fixedname_name(&fn);
 	isc_stdtime_t now = isc_stdtime_now();
 
-	assert_int_equal(dns_test_makeview("view", false, &view),
+	assert_int_equal(dns_test_makeview("view", false, false, &view),
 			 ISC_R_SUCCESS);
 
-	assert_int_equal(dns_keytable_create(mctx, &keytable), ISC_R_SUCCESS);
-	assert_int_equal(dns_ntatable_create(view, loopmgr, &ntatable),
-			 ISC_R_SUCCESS);
+	dns_keytable_create(view, &keytable);
+	dns_ntatable_create(view, loopmgr, &ntatable);
 
 	/* Add a normal key */
 	dns_test_namefromstring("example.com.", &fn);
@@ -245,13 +244,13 @@ ISC_LOOP_TEST_IMPL(add) {
 	assert_int_equal(dns_keytable_add(keytable, false, false, keyname, &ds,
 					  NULL, NULL),
 			 ISC_R_SUCCESS);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 	assert_int_equal(
 		dns_keytable_find(keytable, str2name("example.com"), &keynode),
 		ISC_R_SUCCESS);
 
 	/* Add another key (different keydata) */
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 	create_dsstruct(keyname, 257, 3, 5, keystr2, digest, &ds);
 	assert_int_equal(dns_keytable_add(keytable, false, false, keyname, &ds,
 					  NULL, NULL),
@@ -259,7 +258,7 @@ ISC_LOOP_TEST_IMPL(add) {
 	assert_int_equal(
 		dns_keytable_find(keytable, str2name("example.com"), &keynode),
 		ISC_R_SUCCESS);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Get the keynode for the managed.com key. Ensure the
@@ -272,7 +271,7 @@ ISC_LOOP_TEST_IMPL(add) {
 	assert_int_equal(dns_keynode_initial(keynode), true);
 	dns_keynode_trust(keynode);
 	assert_int_equal(dns_keynode_initial(keynode), false);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Add a different managed key for managed.com, marking it as an
@@ -288,7 +287,7 @@ ISC_LOOP_TEST_IMPL(add) {
 		dns_keytable_find(keytable, str2name("managed.com"), &keynode),
 		ISC_R_SUCCESS);
 	assert_int_equal(dns_keynode_initial(keynode), false);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Add the same managed key again, but this time mark it as a
@@ -303,7 +302,7 @@ ISC_LOOP_TEST_IMPL(add) {
 		dns_keytable_find(keytable, str2name("managed.com"), &keynode),
 		ISC_R_SUCCESS);
 	assert_int_equal(dns_keynode_initial(keynode), false);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Add a managed key at a new node, two.com, marking it as an
@@ -318,7 +317,7 @@ ISC_LOOP_TEST_IMPL(add) {
 		dns_keytable_find(keytable, str2name("two.com"), &keynode),
 		ISC_R_SUCCESS);
 	assert_int_equal(dns_keynode_initial(keynode), true);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Add a different managed key for two.com, marking it as a
@@ -334,7 +333,7 @@ ISC_LOOP_TEST_IMPL(add) {
 		dns_keytable_find(keytable, str2name("two.com"), &keynode),
 		ISC_R_SUCCESS);
 	assert_int_equal(dns_keynode_initial(keynode), true);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * Add a normal key to a name that has a null key.  The null key node
@@ -352,7 +351,7 @@ ISC_LOOP_TEST_IMPL(add) {
 		dns_keytable_find(keytable, str2name("null.example"), &keynode),
 		ISC_R_SUCCESS);
 	assert_ptr_equal(keynode, null_keynode); /* should be the same node */
-	dns_keytable_detachkeynode(keytable, &null_keynode);
+	dns_keynode_detach(&null_keynode);
 
 	/*
 	 * Try to add a null key to a name that already has a key.  It's
@@ -367,9 +366,9 @@ ISC_LOOP_TEST_IMPL(add) {
 					   &null_keynode),
 			 ISC_R_SUCCESS);
 	assert_ptr_equal(keynode, null_keynode);
-	dns_keytable_detachkeynode(keytable, &null_keynode);
+	dns_keynode_detach(&null_keynode);
 
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 	destroy_tables();
 
 	isc_loopmgr_shutdown(loopmgr);
@@ -501,11 +500,11 @@ ISC_LOOP_TEST_IMPL(find) {
 	assert_int_equal(
 		dns_keytable_find(keytable, str2name("example.com"), &keynode),
 		ISC_R_SUCCESS);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 	assert_int_equal(
 		dns_keytable_find(keytable, str2name("null.example"), &keynode),
 		ISC_R_SUCCESS);
-	dns_keytable_detachkeynode(keytable, &keynode);
+	dns_keynode_detach(&keynode);
 
 	/*
 	 * dns_keytable_finddeepestmatch() allows partial match.  Also match
@@ -603,16 +602,15 @@ ISC_LOOP_TEST_IMPL(nta) {
 	dns_view_t *myview = NULL;
 	isc_stdtime_t now = isc_stdtime_now();
 
-	result = dns_test_makeview("view", false, &myview);
+	result = dns_test_makeview("view", false, false, &myview);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
-	result = dns_view_initsecroots(myview, mctx);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	dns_view_initsecroots(myview);
+
 	result = dns_view_getsecroots(myview, &keytable);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
-	result = dns_view_initntatable(myview, loopmgr);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	dns_view_initntatable(myview, loopmgr);
 	result = dns_view_getntatable(myview, &ntatable);
 	assert_int_equal(result, ISC_R_SUCCESS);
 
@@ -686,12 +684,12 @@ ISC_LOOP_TEST_IMPL(nta) {
 	assert_false(covered);
 	assert_true(issecure);
 
+	isc_loopmgr_shutdown(loopmgr);
+
 	/* Clean up */
 	dns_ntatable_detach(&ntatable);
 	dns_keytable_detach(&keytable);
 	dns_view_detach(&myview);
-
-	isc_loopmgr_shutdown(loopmgr);
 }
 
 ISC_TEST_LIST_START
