@@ -67,8 +67,7 @@ ISC_LOOP_TEST_IMPL(notify_start) {
 	isc_buffer_t nbuf;
 	size_t nsize;
 
-	result = ns_test_getclient(NULL, false, &client);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	ns_test_getclient(NULL, false, &client);
 
 	result = dns_test_makeview("view", false, false, &client->view);
 	assert_int_equal(result, ISC_R_SUCCESS);
